@@ -1,7 +1,7 @@
 /*
  * config_mgr.h - class configManager, a class for managing LMMS-configuration
  *
- * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -73,7 +73,7 @@ class configManager : public QDialog
 {
 	Q_OBJECT
 public:
-	static inline configManager * inst( void )
+	static configManager * inst( void )
 	{
 		if( s_instanceOfMe == NULL )
 		{
