@@ -2,7 +2,7 @@
  * export_project_dialog.h - declaration of class exportProjectDialog which is
  *                           responsible for exporting project
  *
- * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -31,12 +31,11 @@
 #include <config.h>
 #endif
 
-
 #include "qt3support.h"
 
 #ifdef QT4
 
-#include <QDialog>
+#include <QtGui/QDialog>
 
 #else
 
@@ -44,15 +43,15 @@
 
 #endif
 
-
 #include "export.h"
 
 
 class QLabel;
 class QPushButton;
-class QComboBox;
 class QProgressBar;
-class QCheckBox;
+
+class comboBox;
+class ledCheckBox;
 class pixmapButton;
 
 
@@ -61,7 +60,7 @@ class exportProjectDialog : public QDialog
 	Q_OBJECT
 public:
 	exportProjectDialog( const QString & _file_name, QWidget * _parent );
-	~exportProjectDialog();
+	virtual ~exportProjectDialog();
 
 
 public slots:
@@ -69,8 +68,8 @@ public slots:
 
 
 protected:
-	void keyPressEvent( QKeyEvent * _ke );
-	void closeEvent( QCloseEvent * _ce );
+	virtual void keyPressEvent( QKeyEvent * _ke );
+	virtual void closeEvent( QCloseEvent * _ce );
 
 
 private slots:
@@ -86,13 +85,14 @@ private:
 									_ext );
 	static Sint16 s_availableBitrates[];
 
+
 	QString m_fileName;
 	QLabel * m_typeLbl;
-	QComboBox * m_typeCombo;
+	comboBox * m_typeCombo;
 	QLabel * m_kbpsLbl;
-	QComboBox * m_kbpsCombo;
-	QCheckBox * m_vbrCb;
-	QCheckBox * m_hqmCb;
+	comboBox * m_kbpsCombo;
+	ledCheckBox * m_vbrCb;
+	ledCheckBox * m_hqmCb;
 	QLabel * m_hourglassLbl;
 	QPushButton * m_exportBtn;
 	QPushButton * m_cancelBtn;
