@@ -1,7 +1,7 @@
 /*
  * group_box.h - LMMS-groupbox
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -44,12 +44,11 @@
 class QPixmap;
 
 
-class groupBox : public QWidget, public engineObject
+class groupBox : public QWidget
 {
 	Q_OBJECT
 public:
-	groupBox( const QString & _caption, QWidget * _parent,
-					engine * _engine, track * _track );
+	groupBox( const QString & _caption, QWidget * _parent, track * _track );
 	virtual ~groupBox();
 
 	bool isActive( void ) const
@@ -57,12 +56,20 @@ public:
 		return( m_led->isChecked() );
 	}
 
+	void saveSettings( QDomDocument & _doc, QDomElement & _this,
+							const QString & _name );
+	void loadSettings( const QDomElement & _this, const QString & _name );
+
 
 public slots:
 	void setState( bool _on, bool _anim = FALSE );
 	void animate( void );
 
 
+signals:
+	void toggled( bool _state );
+
+
 protected:
 	virtual void resizeEvent( QResizeEvent * _re );
 	virtual void mousePressEvent( QMouseEvent * _me );
