@@ -2,7 +2,7 @@
  * instrument.h - declaration of class instrument, which provides a
  *                standard interface for all instrument plugins
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -55,6 +55,9 @@
 // forward-declarations
 class instrumentTrack;
 class notePlayHandle;
+class midiEvent;
+class midiTime;
+class track;
 
 
 class instrument : public QWidget, public plugin
@@ -67,10 +70,11 @@ public:
 	// if the plugin doesn't play each note, it can create an instrument-
 	// play-handle and re-implement this method, so that it mixes it's
 	// output buffer only once per mixer-period
-	virtual void play( void );
+	virtual void play( bool _try_parallelizing = FALSE );
 
 	// to be overloaded by actual plugin
-	virtual void FASTCALL playNote( notePlayHandle * note_to_play );
+	virtual void FASTCALL playNote( notePlayHandle * note_to_play,
+						bool _try_parallelizing );
 
 	// needed for deleting plugin-specific-data of a note - plugin has to
 	// cast void-ptr so that the plugin-data is deleted properly
@@ -85,18 +89,42 @@ public:
 	virtual f_cnt_t FASTCALL beatLen( notePlayHandle * _n ) const;
 
 
-	// instrument-play-handles use this for checking whether they can mark
-	// themselves as done, so that mixer trashes them
-	inline virtual bool valid( void ) const
+	// some instruments need a certain number of release-frames even
+	// if no envelope is active - such instruments can re-implement this
+	// method for returning how many frames they at least like to have for
+	// release
+	virtual f_cnt_t desiredReleaseFrames( void ) const
 	{
-		return( m_valid );
+		return( 0 );
 	}
 
+	// monophonic instruments can re-implement this indicate that they do
+	// not allow more then one note being played at the same time
+	virtual bool isMonophonic( void ) const
+	{
+		return( FALSE );
+	}
+
+	inline virtual bool notePlayHandleBased( void ) const
+	{
+		return( TRUE );
+	}
+
+	// sub-classes can re-implement this for receiving all incoming
+	// MIDI-events except NoteOn and NoteOff
+	inline virtual bool handleMidiEvent( const midiEvent & _me,
+						const midiTime & _time )
+	{
+		return( FALSE );
+	}
 
 	// instantiate instrument-plugin with given name or return NULL
 	// on failure
 	static instrument * FASTCALL instantiate( const QString & _plugin_name,
-						instrumentTrack * _channel_track );
+					instrumentTrack * _channel_track );
+
+	virtual bool isFromTrack( const track * _track ) const;
+
 
 protected:
 	inline instrumentTrack * getInstrumentTrack( void ) const
@@ -104,19 +132,14 @@ protected:
 		return( m_instrumentTrack );
 	}
 
-	// instruments can use this for invalidating themselves, which is for
-	// example neccessary when being destroyed and having instrument-play-
-	// handles running
-	inline void invalidate( void )
-	{
-		m_valid = FALSE;
-		eng()->getMixer()->checkValidityOfPlayHandles();
-	}
+	// instruments may use this to apply a soft fade out at the end of
+	// notes - method does this only if really less or equal
+	// desiredReleaseFrames() frames are left
+	void applyRelease( sampleFrame * buf, const notePlayHandle * _n );
 
 
 private:
 	instrumentTrack * m_instrumentTrack;
-	bool m_valid;
 
 } ;
 
