@@ -1,7 +1,7 @@
 /*
  * instrument_play_handle.h - play-handle for playing an instrument
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -34,7 +34,7 @@ class instrumentPlayHandle : public playHandle
 {
 public:
 	inline instrumentPlayHandle( instrument * _instrument ) :
-		playHandle( INSTRUMENT_PLAY_HANDLE ),
+		playHandle( InstrumentPlayHandle ),
 		m_instrument( _instrument )
 	{
 	}
@@ -44,25 +44,29 @@ public:
 	}
 
 
-	inline virtual void play( void )
+	inline virtual void play( bool _try_parallelizing )
 	{
-		if( m_instrument != NULL )
-		{
-			m_instrument->play();
-		}
+		m_instrument->play( _try_parallelizing );
 	}
 
 	inline virtual bool done( void ) const
 	{
-		return( m_instrument == NULL );
+		return( FALSE );
 	}
 
-	inline virtual void checkValidity( void )
+	virtual bool isFromTrack( const track * _track ) const
 	{
-		if( m_instrument != NULL && !m_instrument->valid() )
-		{
-			m_instrument = NULL;
-		}
+		return( m_instrument->isFromTrack( _track ) );
+	}
+
+	inline virtual bool supportsParallelizing( void ) const
+	{
+		return( m_instrument->supportsParallelizing() );
+	}
+
+	inline virtual void waitForWorkerThread( void )
+	{
+		m_instrument->waitForWorkerThread();
 	}
 
 
