@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -58,7 +58,24 @@ enum midiEventTypes
 	MIDI_ACTIVE_SENSING = 0xFE,
 	MIDI_SYSTEM_RESET = 0xFF,
 	// meta event - for midi files only
-	MIDI_META_EVENT = 0xFF
+	MIDI_META_EVENT = 0xFF,
+} ;
+
+enum midiMetaEvents
+{
+	MIDI_COPYRIGHT = 0x02,
+	MIDI_TRACK_NAME = 0x03,
+	MIDI_INST_NAME = 0x04,
+	MIDI_LYRIC = 0x05,
+	MIDI_MARKER = 0x06,
+	MIDI_CUE_POINT = 0x07,
+	MIDI_PORT_NUMBER = 0x21,
+	MIDI_EOT = 0x2f,
+	MIDI_SET_TEMPO = 0x51,
+	MIDI_SMPTE_OFFSET = 0x54,
+	MIDI_TIME_SIGNATURE = 0x58,
+	MIDI_KEY_SIGNATURE = 0x59,
+	MIDI_SEQUENCER_EVENT = 0x7f
 } ;
 
 
