@@ -2,7 +2,7 @@
  * midi_port.h - abstraction of MIDI-ports which are part of LMMS's MIDI-
  *               sequencing system
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -46,11 +46,11 @@
 
 #include "types.h"
 #include "midi.h"
-#include "midi_time.h"
 
 
 class midiClient;
 class midiEventProcessor;
+class midiTime;
 
 
 // class for abstraction of MIDI-port
