@@ -2,7 +2,7 @@
  * note_play_handle.h - declaration of class notePlayHandle which is needed
  *                      by LMMS-Play-Engine
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -27,45 +27,108 @@
 #ifndef _NOTE_PLAY_HANDLE_H
 #define _NOTE_PLAY_HANDLE_H
 
-#include <qobject.h>
-
 #include "play_handle.h"
 #include "basic_filters.h"
+#include "bb_track.h"
 #include "note.h"
+#include "instrument.h"
+#include "instrument_track.h"
+#include "engine.h"
 
 
-class instrumentTrack;
 class notePlayHandle;
 
 typedef vvector<notePlayHandle *> notePlayHandleVector;
 typedef vvector<const notePlayHandle *> constNotePlayHandleVector;
 
 
-class notePlayHandle : public QObject, public playHandle, public note
+class notePlayHandle : public playHandle, public note
 {
-	Q_OBJECT
 public:
 	void * m_pluginData;
 	basicFilters<> * m_filter;
 
-	float m_frequency;
-
-	notePlayHandle( instrumentTrack * _chnl_trk, const f_cnt_t _frames_ahead,
+	notePlayHandle( instrumentTrack * _instrument_track,
+					const f_cnt_t _offset,
 					const f_cnt_t _frames, const note & _n,
+					notePlayHandle * _parent = NULL,
 					const bool _arp_note = FALSE );
 	virtual ~notePlayHandle();
 
 
-	virtual void play( void );
+	const float & frequency( void )
+	{
+		return( m_frequency );
+	}
+
+	void updateFrequency( void );
+
+	virtual void play( bool _try_parallelizing );
 
 	virtual inline bool done( void ) const
 	{
-		return( ( m_released && m_framesBeforeRelease == 0 &&
-			m_releaseFramesDone >= m_releaseFramesToDo ) ||
-						m_instrumentTrack == NULL );
+		return( m_released && framesLeft() <= 0 );
 	}
 
-	virtual void checkValidity( void );
+	bool willFinishThisPeriod( void ) const
+	{
+		f_cnt_t rftd = m_releaseFramesToDo;
+		f_cnt_t fbr = m_framesBeforeRelease;
+		f_cnt_t rfd = m_releaseFramesDone;
+		if( m_released == TRUE )
+		{
+			f_cnt_t todo = engine::getMixer()->framesPerPeriod();
+			if( arpBaseNote() == TRUE )
+			{
+				rftd = rfd + 2 *
+					engine::getMixer()->framesPerPeriod();
+			}
+			if( fbr )
+			{
+				if( fbr <=
+					engine::getMixer()->framesPerPeriod() )
+				{
+					todo -= fbr;
+					fbr = 0;
+				}
+				else
+				{
+					todo = 0;
+					fbr -=
+					engine::getMixer()->framesPerPeriod();
+				}
+			}
+			if( todo && rfd < rftd )
+			{
+				if( rftd - rfd >= todo )
+				{
+					rfd += todo;
+				}
+				else
+				{
+					rfd = rftd;
+				}
+			}
+		}
+
+		if( arpBaseNote() == TRUE && m_subNotes.size() == 0 )
+		{
+			rfd = rftd;
+		}
+
+		return( ( m_released && fbr == 0 && rfd >= rftd ) );
+	}
+
+	f_cnt_t framesLeft( void ) const;
+
+	inline f_cnt_t framesLeftForCurrentPeriod( void ) const
+	{
+		return( tMin<f_cnt_t>( framesLeft(),
+				engine::getMixer()->framesPerPeriod() ) );
+	}
+
+
+	virtual bool isFromTrack( const track * _track ) const;
 
 
 	void FASTCALL noteOff( const f_cnt_t _s = 0 );
@@ -82,12 +145,6 @@ public:
 
 	f_cnt_t actualReleaseFramesToDo( void ) const;
 
-	// returns how many samples this note is aligned ahead, i.e.
-	// at which position it is inserted in the according buffer
-	inline f_cnt_t framesAhead( void ) const
-	{
-		return ( m_framesAhead );
-	}
 
 	// returns total numbers of frames to play
 	inline f_cnt_t frames( void ) const
@@ -112,17 +169,6 @@ public:
 	// returns volume-level at frame _frame (envelope/LFO)
 	float FASTCALL volumeLevel( const f_cnt_t _frame );
 
-	// adds note-play-handle _n as subnote
-	inline void addSubNote( notePlayHandle * _n )
-	{
-		m_subNotes.push_back( _n );
-		_n->m_baseNote = FALSE;
-		// if there was an arp-note added and this note is a base-note
-		// we set arp-note-flag for indicating that this note is an
-		// arpeggio-base-note
-		m_arpNote = _n->arpNote() && baseNote();
-	}
-
 	// returns instrument-track this note-play-handle plays
 	inline instrumentTrack * getInstrumentTrack( void )
 	{
@@ -164,20 +210,89 @@ public:
 	// belonging to this channel
 	int index( void ) const;
 
-	// note-play-handles belonging to given channel
+	// note-play-handles belonging to given channel, if _all_ph = TRUE,
+	// also released note-play-handles are returned
 	static constNotePlayHandleVector nphsOfInstrumentTrack(
-						const instrumentTrack * _ct );
+			const instrumentTrack * _ct, bool _all_ph = FALSE );
 
 	// return whether given note-play-handle is equal to *this
 	bool operator==( const notePlayHandle & _nph ) const;
 
+	bool bbTrackMuted( void )
+	{
+		return( m_bbTrack && m_bbTrack->muted() );
+	}
+	void setBBTrack( bbTrack * _bb_track )
+	{
+		m_bbTrack = _bb_track;
+	}
+
+
+	virtual bool supportsParallelizing( void ) const
+	{
+		return( m_instrumentTrack->getInstrument()->
+						supportsParallelizing()
+				&&
+			// we must not parallelize note-play-handles, which
+			// belong to instruments that are instrument-play-
+			// handle-driven, because then waitForWorkerThread()
+			// would be additionally called for each
+			// note-play-handle which results in hangups
+			m_instrumentTrack->getInstrument()->
+						notePlayHandleBased() );
+	}
+
+	virtual void waitForWorkerThread( void )
+	{
+		m_instrumentTrack->m_instrument->waitForWorkerThread();
+	}
+
+	void processMidiTime( const midiTime & _time );
+	void resize( const bpm_t _new_bpm );
+
+#if SINGERBOT_SUPPORT
+	int patternIndex( void )
+	{
+		return( m_patternIndex );
+	}
+
+	void setPatternIndex( int _i )
+	{
+		m_patternIndex = _i;
+	}
+#endif
+
 
 private:
+	class baseDetuning
+	{
+	public:
+		baseDetuning( detuningHelper * _detuning );
+
+		int level( void )
+		{
+			return( m_level );
+		}
+
+		void setLevel( int _level );
+
+		float value( void )
+		{
+			return( m_value );
+		}
+
+
+	private:
+		int m_level;
+		float m_value;
+		detuningHelper * m_detuning;
+
+	} ;
+
+
 	instrumentTrack * m_instrumentTrack;	// needed for calling
 					// instrumentTrack::playNote
 	f_cnt_t m_frames;		// total frames to play
-	f_cnt_t m_framesAhead;		// numbers of frames ahead in buffer
-					// to mix in
 	f_cnt_t m_totalFramesPlayed;	// total frame-counter - used for
 					// figuring out whether a whole note
 					// has been played
@@ -195,11 +310,18 @@ private:
 					// an arpeggio (either base-note or
 					// sub-note)
 	bool m_muted;			// indicates whether note is muted
+	bbTrack * m_bbTrack;		// related BB track
+#if SINGERBOT_SUPPORT
+	int m_patternIndex;		// position among relevant notes
+#endif
 
+	// tempo reaction
+	bpm_t m_orig_bpm;		// original bpm
+	f_cnt_t m_orig_frames;		// original m_frames
 
-private slots:
-	void processMidiTime( const midiTime & _time );
-	void updateFrequency( void );
+	float m_frequency;
+
+	baseDetuning * m_base_detuning;
 
 } ;
 
