@@ -2,7 +2,7 @@
  * pattern.h - declaration of class pattern, which contains all informations
  *             about a pattern
  *
- * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -31,34 +31,32 @@
 
 #ifdef QT4
 
-#include <QVector>
-#include <QWidget>
-#include <QMutex>
-#include <QDialog>
-#include <QThread>
+#include <QtCore/QVector>
+#include <QtGui/QWidget>
+#include <QtGui/QDialog>
+#include <QtCore/QThread>
+#include <QtGui/QPixmap>
 
 #else
 
 #include <qvaluevector.h>
 #include <qwidget.h>
-#include <qmutex.h>
 #include <qdialog.h>
 #include <qthread.h>
+#include <qpixmap.h>
 
 #endif
 
 
 #include "note.h"
 #include "track.h"
-#include "mixer.h"
 
 
 class QAction;
-class QPixmap;
 class QProgressBar;
 class QPushButton;
 
-class channelTrack;
+class instrumentTrack;
 class patternFreezeThread;
 class sampleBuffer;
 
@@ -77,35 +75,30 @@ public:
 		BEAT_PATTERN, MELODY_PATTERN/*, AUTOMATION_PATTERN*/
 	} ;
 
-	pattern( channelTrack * _channel_track );
-	pattern( const pattern & _pat_to_copy ) FASTCALL;
+	pattern( instrumentTrack * _channel_track );
+	pattern( const pattern & _pat_to_copy );
 	virtual ~pattern();
 
 	void init( void );
 
 
-	virtual void FASTCALL movePosition( const midiTime & _pos );
-
-
 	virtual midiTime length( void ) const;
 
-	note * FASTCALL addNote( const note & _new_note );
+	note * FASTCALL addNote( const note & _new_note,
+					const bool _quant_pos = TRUE );
 
 	void FASTCALL removeNote( const note * _note_to_del );
 
-	note * FASTCALL rearrangeNote( const note * _note_to_proc );
+	note * FASTCALL rearrangeNote( const note * _note_to_proc,
+					const bool _quant_pos = TRUE );
 
 	void clearNotes( void );
 	
-	inline noteVector & notes( void )
+	inline const noteVector & notes( void )
 	{
 		return( m_notes );
 	}
 
-	note * FASTCALL noteAt( int _note_num );
-
-	void FASTCALL setNoteAt( int _note_num, note _new_note );
-
 	// pattern-type stuff
 	inline patternTypes type( void ) const
 	{
@@ -139,10 +132,10 @@ public:
 		return( m_frozenPattern != NULL );
 	}
 
-	// if channel-track recognizes that this pattern is frozen, it calls
-	// this instead of playing all the notes
-	void FASTCALL playFrozenData( sampleFrame * _ab, Uint32 _start_frame,
-							Uint32 _frames );
+	sampleBuffer * getFrozenPattern( void )
+	{
+		return( m_frozenPattern );
+	}
 
 	// settings-management
 	virtual void FASTCALL saveSettings( QDomDocument & _doc,
@@ -153,11 +146,17 @@ public:
 		return( "pattern" );
 	}
 
-	inline channelTrack * getChannelTrack( void )
+	inline instrumentTrack * getInstrumentTrack( void )
 	{
-		return( m_channelTrack );
+		return( m_instrumentTrack );
 	}
 
+	bool empty( void );
+
+
+public slots:
+	virtual void update( void );
+
 
 protected slots:
 	void openInPianoRoll( bool _c );
@@ -180,24 +179,30 @@ protected:
 	virtual void constructContextMenu( QMenu * );
 	virtual void mouseDoubleClickEvent( QMouseEvent * _me );
 	virtual void mousePressEvent( QMouseEvent * _me );
-	virtual void wheelEvent( QWheelEvent * _we );
 	virtual void paintEvent( QPaintEvent * _pe );
+	virtual void resizeEvent( QResizeEvent * _re )
+	{
+		m_needsUpdate = TRUE;
+		trackContentObject::resizeEvent( _re );
+	}
+	virtual void wheelEvent( QWheelEvent * _we );
 
 	void ensureBeatNotes( void );
 	void updateBBTrack( void );
 
 
 private:
-	static QPixmap * s_patternBg;
 	static QPixmap * s_stepBtnOn;
 	static QPixmap * s_stepBtnOverlay;
 	static QPixmap * s_stepBtnOff;
 	static QPixmap * s_stepBtnOffLight;
 	static QPixmap * s_frozen;
 
+	QPixmap m_paintPixmap;
+	bool m_needsUpdate;
 
 	// general stuff
-	channelTrack * m_channelTrack;
+	instrumentTrack * m_instrumentTrack;
 
 	patternTypes m_patternType;
 	QString m_name;
@@ -207,7 +212,6 @@ private:
 	int m_steps;
 
 	// pattern freezing
-	QMutex m_frozenPatternMutex;
 	sampleBuffer * m_frozenPattern;
 	bool m_freezing;
 	volatile bool m_freezeAborted;
