@@ -2,7 +2,7 @@
  * piano_roll.h - declaration of class pianoRoll which is a window where you
  *                can set and edit notes in an easy way
  *
- * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -31,8 +31,8 @@
 
 #ifdef QT4
 
-#include <QWidget>
-#include <QVector>
+#include <QtGui/QWidget>
+#include <QtCore/QVector>
 
 #else
 
@@ -43,58 +43,73 @@
 
 #include "types.h"
 #include "note.h"
+#include "journalling_object.h"
 
 
-class QComboBox;
 class QPainter;
 class QPixmap;
 class QScrollBar;
 
-class toolButton;
-class pattern;
+class comboBox;
 class notePlayHandle;
+class pattern;
 class timeLine;
-class lmmsMainWin;
+class toolButton;
 
 
-
-class pianoRoll : public QWidget
+class pianoRoll : public QWidget, public journallingObject
 {
 	Q_OBJECT
 public:
-	static inline pianoRoll * inst( void )
+	void FASTCALL setCurrentPattern( pattern * _new_pattern );
+
+	inline bool isRecording( void ) const
 	{
-		if( s_instanceOfMe == NULL )
-		{
-			s_instanceOfMe = new pianoRoll();
-		}
-		return( s_instanceOfMe );
+		return( m_recording );
 	}
 
-	void FASTCALL setCurrentPattern( pattern * _new_pattern );
 	inline const pattern * currentPattern( void ) const
 	{
 		return( m_pattern );
 	}
+
 	inline bool validPattern( void ) const
 	{
 		return( m_pattern != NULL );
 	}
 
+	int quantization( void ) const;
+
+
+	virtual void FASTCALL saveSettings( QDomDocument & _doc,
+							QDomElement & _parent );
+	virtual void FASTCALL loadSettings( const QDomElement & _this );
+	inline virtual QString nodeName( void ) const
+	{
+		return( "pianoroll" );
+	}
+
 
 protected:
-	void closeEvent( QCloseEvent * _ce );
-	void paintEvent( QPaintEvent * _pe );
-	void resizeEvent( QResizeEvent * _re );
-	void mousePressEvent( QMouseEvent * _me );
-	void mouseReleaseEvent( QMouseEvent * _me );
-	void mouseMoveEvent( QMouseEvent * _me );
-	void keyPressEvent( QKeyEvent * _ke );
-	void wheelEvent( QWheelEvent * _we );
+	virtual void closeEvent( QCloseEvent * _ce );
+	virtual void keyPressEvent( QKeyEvent * _ke );
+	virtual void keyReleaseEvent( QKeyEvent * _ke );
+	virtual void leaveEvent( QEvent * _e );
+	virtual void mousePressEvent( QMouseEvent * _me );
+	virtual void mouseReleaseEvent( QMouseEvent * _me );
+	virtual void mouseMoveEvent( QMouseEvent * _me );
+	virtual void paintEvent( QPaintEvent * _pe );
+	virtual void resizeEvent( QResizeEvent * _re );
+	virtual void wheelEvent( QWheelEvent * _we );
+#ifdef BUILD_LINUX
+	virtual bool x11Event( XEvent * _xe );
+#endif
 
-	int FASTCALL getKey( int _y );
-	inline void drawNoteRect( QPainter & _p, Uint16 _x, Uint16 _y,
-					Sint16 _width, bool _is_selected );
+	int FASTCALL getKey( int _y ) const;
+	static inline void drawNoteRect( QPainter & _p, Uint16 _x, Uint16 _y,
+					Sint16 _width,
+					const bool _is_selected,
+					const bool _is_step_note );
 	void removeSelection( void );
 	void selectAll( void );
 	void FASTCALL getSelectedNotes( noteVector & _selected_notes );
@@ -132,7 +147,8 @@ private:
 		DRAW,
 		ERASE,
 		SELECT,
-		MOVE
+		MOVE,
+		OPEN
 	} ;
 
 	enum actions
@@ -154,7 +170,14 @@ private:
 	} ;
 
 
-	static pianoRoll * s_instanceOfMe;
+	pianoRoll( void );
+	pianoRoll( const pianoRoll & );
+	virtual ~pianoRoll();
+
+	midiTime newNoteLen( void ) const;
+
+	void updatePaintPixmap( QPixmap & _p );
+
 
 	static QPixmap * s_whiteKeyBigPm;
 	static QPixmap * s_whiteKeySmallPm;
@@ -163,6 +186,7 @@ private:
 	static QPixmap * s_toolErase;
 	static QPixmap * s_toolSelect;
 	static QPixmap * s_toolMove;
+	static QPixmap * s_toolOpen;
 
 	static pianoRollKeyTypes prKeyOrder[];
 
@@ -182,7 +206,9 @@ private:
 	toolButton * m_copyButton;
 	toolButton * m_pasteButton;
 
-	QComboBox * m_zoomingComboBox;
+	comboBox * m_zoomingComboBox;
+	comboBox * m_quantizeComboBox;
+	comboBox * m_noteLenComboBox;
 
 
 	pattern * m_pattern;
@@ -211,10 +237,8 @@ private:
 	midiTime m_lenOfNewNotes;
 
 	int m_startKey;			// first key when drawing
-	int m_keyMouseOver;
 	int m_lastKey;
 
-	noteVector m_notesToCopy;
 	noteVector m_selNotesForMove;
 
 
@@ -224,13 +248,16 @@ private:
 	timeLine * m_timeLine;
 	bool m_scrollBack;
 
+	void copy_to_clipboard( const noteVector & _notes ) const;
 
-	pianoRoll( void );
-	pianoRoll( const pianoRoll & );
-	~pianoRoll();
+	void drawDetuningInfo( QPainter & _p, note * _n, Uint16 _x, Uint16 _y );
+	bool mouseOverNote( void );
+	note * noteUnderMouse( void );
+	noteVector::const_iterator noteIteratorUnderMouse( void );
 
 
-	friend class lmmsMainWin;
+
+	friend class engine;
 
 
 signals:
