@@ -1,7 +1,7 @@
 /*
  * pixmap_button.h - declaration of class pixmapButton
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -47,7 +47,7 @@ class pixmapButton : public automatableButton
 	Q_OBJECT
 public:
 	pixmapButton( QWidget * _parent, const QString & _name,
-					engine * _engine, track * _track );
+							track * _track );
 	virtual ~pixmapButton();
 
 	void setActiveGraphic( const QPixmap & _pm );
