@@ -1,7 +1,7 @@
 /*
  * plugin_browser.h - include file for pluginBrowser
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -55,11 +55,11 @@
 class trackContainer;
 
 
-class pluginBrowser : public sideBarWidget, public engineObject
+class pluginBrowser : public sideBarWidget
 {
 	Q_OBJECT
 public:
-	pluginBrowser( QWidget * _parent, engine * _engine );
+	pluginBrowser( QWidget * _parent );
 	virtual ~pluginBrowser();
 
 
@@ -73,12 +73,11 @@ private:
 
 
 
-class pluginDescWidget : public QWidget, public engineObject
+class pluginDescWidget : public QWidget
 {
 	Q_OBJECT
 public:
-	pluginDescWidget( const plugin::descriptor & _pd, QWidget * _parent,
-							engine * _engine );
+	pluginDescWidget( const plugin::descriptor & _pd, QWidget * _parent );
 	virtual ~pluginDescWidget();
 
 
