@@ -2,7 +2,7 @@
  * sample_track.h - class sampleTrack, a track which provides arrangement of
  *                  samples
  *
- * Copyright (c) 2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -31,7 +31,7 @@
 
 #ifdef QT4
 
-#include <QDialog>
+#include <QtGui/QDialog>
 
 #else
 
@@ -41,12 +41,13 @@
 
 
 #include "track.h"
-#include "sample_buffer.h"
 
-
-class nameLabel;
-class audioPort;
 class QLabel;
+class audioPort;
+class effectLabel;
+class sampleBuffer;
+class volumeKnob;
+
 //class sampleTCOSettingsDialog;
 
 
@@ -58,8 +59,6 @@ public:
 	virtual ~sampleTCO();
 
 	virtual void FASTCALL changeLength( const midiTime & _length );
-	void FASTCALL play( sampleFrame * _ab, Uint32 _start_frame,
-							Uint32 _frames );
 	const QString & sampleFile( void ) const;
 
 	virtual void FASTCALL saveSettings( QDomDocument & _doc,
@@ -70,11 +69,15 @@ public:
 		return( "sampletco" );
 	}
 
+	sampleBuffer * getSampleBuffer( void )
+	{
+		return( m_sampleBuffer );
+	}
+
 
 public slots:
 	void setSampleFile( const QString & _sf );
-	void updateLength( int = 0 );
-
+	void updateLength( bpm_t = 0 );
 
 protected:
 	virtual void dragEnterEvent( QDragEnterEvent * _dee );
@@ -86,7 +89,7 @@ protected:
 
 
 private:
-	sampleBuffer m_sampleBuffer;
+	sampleBuffer * m_sampleBuffer;
 
 
 	//friend class sampleTCOSettingsDialog;
@@ -127,8 +130,8 @@ public:
 
 	virtual trackTypes type( void ) const;
 	virtual bool FASTCALL play( const midiTime & _start,
-					Uint32 _start_frame, Uint32 _frames,
-					Uint32 _frame_base,
+						const fpp_t _frames,
+						const f_cnt_t _frame_base,
 							Sint16 _tco_num = -1 );
 	virtual trackContentObject * FASTCALL createTCO( const midiTime &
 									_pos );
@@ -139,8 +142,11 @@ public:
 	virtual void FASTCALL loadTrackSpecificSettings( const QDomElement &
 									_this );
 
+	inline audioPort * getAudioPort( void )
+	{
+		return( m_audioPort );
+	}
 
-public slots:
 	virtual QString nodeName( void ) const
 	{
 		return( "sampletrack" );
@@ -148,8 +154,10 @@ public slots:
 
 
 private:
-	nameLabel * m_trackLabel;
+	effectLabel * m_trackLabel;
 	audioPort * m_audioPort;
+	
+	volumeKnob * m_volumeKnob;
 
 } ;
 
