@@ -1,7 +1,7 @@
 /*
  * setup_dialog.h - dialog for setting up LMMS
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -53,7 +53,7 @@ class QSlider;
 class tabBar;
 
 
-class setupDialog : public QDialog, public engineObject
+class setupDialog : public QDialog
 {
 	Q_OBJECT
 public:
@@ -63,8 +63,7 @@ public:
 		AUDIO_SETTINGS, MIDI_SETTINGS
 	} ;
 
-	setupDialog( engine * _engine,
-				configTabs _tab_to_open = GENERAL_SETTINGS );
+	setupDialog( configTabs _tab_to_open = GENERAL_SETTINGS );
 	virtual ~setupDialog();
 
 
@@ -83,7 +82,9 @@ private slots:
 	void setVSTDir( const QString & _vd );
 	void setArtworkDir( const QString & _ad );
 	void setFLDir( const QString & _fd );
-
+	void setLADSPADir( const QString & _fd );
+	void setSTKDir( const QString & _fd );
+	
 	// audio settings widget
 	void audioInterfaceChanged( const QString & _driver );
 	void displayAudioHelp( void );
@@ -99,15 +100,18 @@ private slots:
 	void toggleNoWizard( bool _enabled );
 	void toggleNoMsgAfterSetup( bool _enabled );
 	void toggleDisplaydBV( bool _enabled );
+	void toggleNoMMPZ( bool _enabled );
 
 	void openWorkingDir( void );
 	void openVSTDir( void );
 	void openArtworkDir( void );
 	void openFLDir( void );
-
+	void openLADSPADir( void );
+	void openSTKDir( void );
 
 	void toggleDisableChActInd( bool _disabled );
 	void toggleManualChPiano( bool _enabled );
+	void setParallelizingLevel( int _level );
 
 
 private:
@@ -123,31 +127,42 @@ private:
 	bool m_noWizard;
 	bool m_noMsgAfterSetup;
 	bool m_displaydBV;
+	bool m_noMMPZ;
 
 
 	QLineEdit * m_wdLineEdit;
 	QLineEdit * m_vdLineEdit;
 	QLineEdit * m_adLineEdit;
 	QLineEdit * m_fdLineEdit;
+	QLineEdit * m_ladLineEdit;
+#ifdef HAVE_STK_H
+	QLineEdit * m_stkLineEdit;
+#endif
 
 	QString m_workingDir;
 	QString m_vstDir;
 	QString m_artworkDir;
 	QString m_flDir;
-
+	QString m_ladDir;
+#ifdef HAVE_STK_H
+	QString m_stkDir;
+#endif
 
 	bool m_disableChActInd;
 	bool m_manualChPiano;
-
+	int m_parLevel;
 
 	typedef QMap<QString, audioDevice::setupWidget *> aswMap;
 	typedef QMap<QString, midiClient::setupWidget *> mswMap;
+	typedef QMap<QString, QString> trMap;
 
 	QComboBox * m_audioInterfaces;
 	aswMap m_audioIfaceSetupWidgets;
+	trMap m_audioIfaceNames;
 
 	QComboBox * m_midiInterfaces;
 	mswMap m_midiIfaceSetupWidgets;
+	trMap m_midiIfaceNames;
 
 
 } ;
