@@ -2,7 +2,7 @@
  * string_pair_drag.h - class stringPairDrag which provides general support
  *                      for drag'n'drop of string-pairs
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,8 +18,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -39,23 +39,19 @@
 #endif
 
 
-#include "engine.h"
-
-
 class QPixmap;
 
 
 class stringPairDrag : public
 #ifdef QT4
-				QDrag,
+				QDrag
 #else
-				QStoredDrag,
+				QStoredDrag
 #endif
-			public engineObject
 {
 public:
 	stringPairDrag( const QString & _key, const QString & _value,
-			const QPixmap & _icon, QWidget * _w, engine * _engine );
+					const QPixmap & _icon, QWidget * _w );
 	~stringPairDrag();
 
 	static bool processDragEnterEvent( QDragEnterEvent * _dee,
@@ -63,6 +59,11 @@ public:
 	static QString decodeKey( QDropEvent * _de );
 	static QString decodeValue( QDropEvent * _de );
 
+	static const char * mimeType( void )
+	{
+		return( "application/x-lmms-stringpair" );
+	}
+
 } ;
 
 
