@@ -1,7 +1,7 @@
 /*
  * timeline.h - class timeLine, representing a time-line with position marker
  *
- * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -30,7 +30,7 @@
 
 #ifdef QT4
 
-#include <QWidget>
+#include <QtGui/QWidget>
 
 #else
 
@@ -47,7 +47,7 @@ class nStateButton;
 class textFloat;
 
 
-class timeLine : public QWidget
+class timeLine : public QWidget, public journallingObject
 {
 	Q_OBJECT
 public:
@@ -69,7 +69,7 @@ public:
 
 	timeLine( int _xoff, int _yoff, float _ppt, songEditor::playPos & _pos,
 				const midiTime & _begin, QWidget * _parent );
-	~timeLine();
+	virtual ~timeLine();
 
 	inline songEditor::playPos & pos( void )
 	{
@@ -116,12 +116,24 @@ public:
 	void addToolButtons( QWidget * _tool_bar );
 
 
+	virtual void FASTCALL saveSettings( QDomDocument & _doc,
+							QDomElement & _parent );
+	virtual void FASTCALL loadSettings( const QDomElement & _this );
+	inline virtual QString nodeName( void ) const
+	{
+		return( "timeline" );
+	}
+
+
 public slots:
-	void updatePosition( const midiTime & = 0 );
+	void updatePosition( const midiTime & );
+	void updatePosition( void )
+	{
+		updatePosition( midiTime() );
+	}
 	void toggleAutoScroll( int _n );
 	void toggleLoopPoints( int _n );
 	void toggleBehaviourAtStop( int _n );
-	void checkForUpdatedPosition( void );
 
 
 protected:
@@ -173,6 +185,7 @@ private:
 
 signals:
 	void positionChanged( const midiTime & _t );
+	void loopPointStateLoaded( int _n );
 
 } ;
 
