@@ -1,8 +1,8 @@
 /*
  * volume_knob.h - defines a knob that display it's value as either a
- *                 percentage or in dbV.
+ *                 percentage or in dBV.
  *
- * Copyright (c) 2006  Danny McRae <khjklujn/at/users.sourceforge.net>
+ * Copyright (c) 2006-2007  Danny McRae <khjklujn/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -18,34 +18,24 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
 #ifndef _VOLUME_KNOB_H
 #define _VOLUME_KNOB_H
 
-#ifdef QT4
 
-#include <QtGui/QPixmap>
-
-#else
-
-#include <qpixmap.h>
-
-#endif
-
-#include "types.h"
 #include "knob.h"
 
 
-class volumeKnob: public knob
+class volumeKnob : public knob
 {
 	Q_OBJECT
 public:
 	volumeKnob( int _knob_num, QWidget * _parent, const QString & _name,
-					engine * _engine, track * _track );
+							track * _track );
 	virtual ~volumeKnob();
 
 
@@ -57,6 +47,7 @@ protected:
 	virtual void mousePressEvent( QMouseEvent * _me );
 	virtual void mouseMoveEvent( QMouseEvent * _me );
 	virtual void wheelEvent( QWheelEvent * _we );
+
 } ;
 
 #endif
