@@ -1,7 +1,7 @@
 /*
  * flp_import.cpp - support for importing FLP-files
  *
- * Copyright (c) 2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2006-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  * 
@@ -17,34 +17,35 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
 
 #include "flp_import.h"
-#include "project_notes.h"
+#include "arp_and_chords_tab_widget.h"
+#include "basic_filters.h"
 #include "bb_editor.h"
-#include "song_editor.h"
 #include "bb_track.h"
-#include "track_container.h"
-#include "instrument_track.h"
-#include "pattern.h"
-#include "project_journal.h"
-#include "instrument.h"
+#include "combobox.h"
 #include "config_mgr.h"
+#include "debug.h"
+#include "engine.h"
 #include "envelope_tab_widget.h"
 #include "envelope_and_lfo_widget.h"
+#include "group_box.h"
+#include "instrument.h"
+#include "instrument_track.h"
 #include "knob.h"
 #include "oscillator.h"
-#include "basic_filters.h"
-#include "combobox.h"
-#include "group_box.h"
-#include "arp_and_chords_tab_widget.h"
-#include "tempo_sync_knob.h"
+#include "pattern.h"
 #include "piano_widget.h"
-#include "debug.h"
+#include "project_journal.h"
+#include "project_notes.h"
+#include "song_editor.h"
+#include "tempo_sync_knob.h"
+#include "track_container.h"
 
 
 #ifdef QT4
@@ -65,6 +66,10 @@
 
 #endif
 
+#ifdef HAVE_CTYPE_H
+#include <ctype.h>
+#endif
+
 #define makeID(_c0, _c1, _c2, _c3) \
 	( ( _c0 ) | ( ( _c1 ) << 8 ) | ( ( _c2 ) << 16 ) | ( ( _c3 ) << 24 ) )
 
@@ -80,8 +85,9 @@ plugin::descriptor flpimport_plugin_descriptor =
 			"Filter for importing FL Studio projects into LMMS" ),
 	"Tobias Doerffel <tobydox/at/users/dot/sf/dot/net>",
 	0x0100,
-	plugin::IMPORT_FILTER,
-	new QPixmap()
+	plugin::ImportFilter,
+	new QPixmap(),
+	NULL
 } ;
 
 
@@ -109,7 +115,7 @@ extern QString outstring;
 }
 
 
-void dump_mem( const void * buffer, uint n_bytes )
+static void dump_mem( const void * buffer, uint n_bytes )
 {
 	uchar * cp = (uchar *) buffer;
 	for( uint k = 0; k < n_bytes; ++k )
@@ -122,7 +128,7 @@ void dump_mem( const void * buffer, uint n_bytes )
 
 
 flpImport::flpImport( const QString & _file ) :
-	importFilter( _file, &flpimport_plugin_descriptor, NULL )
+	importFilter( _file, &flpimport_plugin_descriptor )
 {
 }
 
@@ -241,9 +247,9 @@ bool flpImport::tryImport( trackContainer * _tc )
 
 	int ev_cnt = 0;
 
-	_tc->eng()->getSongEditor()->clearProject();
-	const bool is_journ = _tc->eng()->getProjectJournal()->isJournalling();
-	_tc->eng()->getProjectJournal()->setJournalling( FALSE );
+	engine::getSongEditor()->clearProject();
+	const bool is_journ = engine::getProjectJournal()->isJournalling();
+	engine::getProjectJournal()->setJournalling( FALSE );
 
 
 	while( file().atEnd() == FALSE )
@@ -328,7 +334,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 
 			case FLP_MainVol:
 				printf( "main-volume: %d\n", data );
-				_tc->eng()->getSongEditor()->setMasterVolume(
+				engine::getSongEditor()->setMasterVolume(
 					static_cast<volume>( data * 100 /
 									128 ) );
 				break;
@@ -359,7 +365,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 				printf( "new channel\n" );
 
 				it = dynamic_cast<instrumentTrack *>(
-	track::create( track::CHANNEL_TRACK, _tc->eng()->getBBEditor() ) );
+	track::create( track::INSTRUMENT_TRACK, engine::getBBEditor() ) );
 				assert( it != NULL );
 				i_tracks.push_back( it );
 				it_inst = it->loadInstrument(
@@ -379,7 +385,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 
 			case FLP_Tempo:
 				printf( "tempo: %d\n", data );
-				_tc->eng()->getSongEditor()->setTempo( data );
+				engine::getSongEditor()->setTempo( data );
 				break;
 
 			case FLP_CurrentPatNum:
@@ -412,8 +418,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 				break;
 
 			case FLP_MainPitch:
-				_tc->eng()->getSongEditor()->setMasterPitch(
-									data );
+				engine::getSongEditor()->setMasterPitch( data );
 				break;
 
 			case FLP_Resonance:
@@ -476,7 +481,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 			case FLP_MiddleNote:
 				data += 8;
 				it->setBaseNote( data );
-				it->m_pianoWidget->update();
+				it->getPianoWidget()->update();
 				break;
 
 			case FLP_DelayReso:
@@ -528,7 +533,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 				ba.resetRawData( text, text_len );
 #endif
 
-				_tc->eng()->getProjectNotes()->setText( out );
+				engine::getProjectNotes()->setText( out );
 				outstring = "";
 				break;
 			}
@@ -630,7 +635,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 				const arpAndChordsTabWidget::arpDirections
 					mappedArpDir[] =
 				{
-					arpAndChordsTabWidget::OFF,
+					arpAndChordsTabWidget::UP,
 					arpAndChordsTabWidget::UP,
 					arpAndChordsTabWidget::DOWN,
 					arpAndChordsTabWidget::UP_AND_DOWN,
@@ -640,16 +645,14 @@ bool flpImport::tryImport( trackContainer * _tc )
 				const Uint32 * p = (const Uint32 *) text;
 				arpAndChordsTabWidget * actw = it->m_arpWidget;
 				actw->m_arpDirectionBtnGrp->setValue(
-						mappedArpDir[p[10]] - 1 );
+							mappedArpDir[p[10]] );
 				actw->m_arpRangeKnob->setValue( p[11] );
 				actw->m_arpComboBox->setValue( p[12] );
 				actw->m_arpTimeKnob->setValue( p[13] / 8.0f );
 							////	100.0f );
 				actw->m_arpGateKnob->setValue( p[14] * 100.0f /
 									48.0f );
-				actw->m_arpGroupBox->setState(
-					mappedArpDir[p[10]] !=
-						arpAndChordsTabWidget::OFF );
+				actw->m_arpGroupBox->setState( p[10] > 0 );
 				printf( "channel params: " );
 				dump_mem( text, text_len );
 				//printf( "channel params: arpdir: %d  range: %d  time: %d  gate: %d\n", p[10], p[11], p[13], p[14] );
@@ -696,6 +699,8 @@ bool flpImport::tryImport( trackContainer * _tc )
 
 			case FLP_FilterParams:
 			{
+				// TODO: Dirty hack!
+				// SIMPLE_FLT_CNT equals to old DOUBLE_LOWPASS
 				const basicFilters<>::filterTypes
 								mappedFilter[] =
 				{
@@ -704,9 +709,9 @@ bool flpImport::tryImport( trackContainer * _tc )
 					basicFilters<>::BANDPASS_CSG,
 					basicFilters<>::HIPASS,
 					basicFilters<>::NOTCH,
-					basicFilters<>::DOUBLE_LOWPASS,
+					basicFilters<>::SIMPLE_FLT_CNT,
 					basicFilters<>::LOWPASS,
-					basicFilters<>::DOUBLE_LOWPASS
+					basicFilters<>::SIMPLE_FLT_CNT
 				} ;
 				Uint32 * p = (Uint32 *) text;
 				envelopeTabWidget * etw = it->m_envWidget;
@@ -734,7 +739,8 @@ bool flpImport::tryImport( trackContainer * _tc )
 			{
 				//dump_mem( text, text_len );
 				const int bpn = 20;
-				for( Uint32 i = 0; i*bpn < text_len; ++i )
+				Uint32 imax = ( text_len + bpn - 1 ) / bpn;
+				for( Uint32 i = 0; i < imax; ++i )
 				{
 					int ch = *( text + i*bpn + 6 );
 					int pos = *( (int *)( text + i*bpn ) );
@@ -743,7 +749,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 									8 ) );
 					pos /= 6;
 					len /= 6;
-					note n( NULL, len, pos );
+					note n( len, pos );
 					n.setKey( key );
 					m_notes.push_back( qMakePair(
 				num_channels * current_pattern + ch, n ) );
@@ -810,10 +816,10 @@ bool flpImport::tryImport( trackContainer * _tc )
 		const int ch = ( *it ) >> 16;
 		const csize pat = ( ( *it ) & 0xffff ) / 16;
 		const csize pos = ( ( ( *it ) & 0xffff ) % 16 ) * 4;
-		while( _tc->eng()->getBBEditor()->numOfBBs() <= pat )
+		while( engine::getBBEditor()->numOfBBs() <= pat )
 		{
 			track::create( track::BB_TRACK,
-						_tc->eng()->getSongEditor() );
+						engine::getSongEditor() );
 		}
 		pattern * p = dynamic_cast<pattern *>(
 						i_tracks[ch]->getTCO( pat ) );
@@ -821,7 +827,7 @@ bool flpImport::tryImport( trackContainer * _tc )
 		{
 			continue;
 		}
-		p->setNoteAt( pos / 4, note( NULL, -64, pos ) );
+		p->addNote( note( -64, pos ), FALSE );
 	}
 
 	// now process all notes
@@ -835,10 +841,10 @@ bool flpImport::tryImport( trackContainer * _tc )
 		{
 			continue;
 		}
-		while( _tc->eng()->getBBEditor()->numOfBBs() <= pat )
+		while( engine::getBBEditor()->numOfBBs() <= pat )
 		{
 			track::create( track::BB_TRACK,
-						_tc->eng()->getSongEditor() );
+						engine::getSongEditor() );
 #ifdef QT4
 			qApp->processEvents( QEventLoop::AllEvents, 100 );
 #else
@@ -862,10 +868,10 @@ bool flpImport::tryImport( trackContainer * _tc )
 		{
 			continue;
 		}
-		while( _tc->eng()->getBBEditor()->numOfBBs() <= pat_num )
+		while( engine::getBBEditor()->numOfBBs() <= pat_num )
 		{
 			track::create( track::BB_TRACK,
-						_tc->eng()->getSongEditor() );
+						engine::getSongEditor() );
 #ifdef QT4
 			qApp->processEvents( QEventLoop::AllEvents, 100 );
 #else
@@ -873,17 +879,17 @@ bool flpImport::tryImport( trackContainer * _tc )
 #endif
 		}
 		
-		bbTrack * bbt = bbTrack::findBBTrack( pat_num, _tc->eng() );
+		bbTrack * bbt = bbTrack::findBBTrack( pat_num );
 		trackContentObject * tco = bbt->addTCO( bbt->createTCO( 0 ) );
 		tco->movePosition( midiTime( ( ( *it ) & 0xffff ) * 64 ) );
 	}
 
-	if( (csize) project_cur_pat < _tc->eng()->getBBEditor()->numOfBBs() )
+	if( (csize) project_cur_pat < engine::getBBEditor()->numOfBBs() )
 	{
-		_tc->eng()->getBBEditor()->setCurrentBB( project_cur_pat );
+		engine::getBBEditor()->setCurrentBB( project_cur_pat );
 	}
 
-	_tc->eng()->getProjectJournal()->setJournalling( is_journ );
+	engine::getProjectJournal()->setJournalling( is_journ );
         return( TRUE );
 }
 
