@@ -1,7 +1,7 @@
 /*
  * triple_oscillator.cpp - powerful instrument with three oscillators
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
  
@@ -44,21 +44,21 @@
 
 
 #include "triple_oscillator.h"
-#include "song_editor.h"
-#include "instrument_track.h"
-#include "note_play_handle.h"
-#include "knob.h"
-#include "buffer_allocator.h"
-#include "debug.h"
-#include "tooltip.h"
-#include "sample_buffer.h"
 #include "automatable_button.h"
+#include "debug.h"
+#include "engine.h"
+#include "instrument_track.h"
+#include "knob.h"
+#include "note_play_handle.h"
 #include "pixmap_button.h"
+#include "sample_buffer.h"
+#include "song_editor.h"
+#include "tooltip.h"
+#include "volume_knob.h"
 
 
 #undef SINGLE_SOURCE_COMPILE
 #include "embed.cpp"
-#include "volume_knob.h"
 
 
 extern "C"
@@ -73,24 +73,17 @@ plugin::descriptor tripleoscillator_plugin_descriptor =
 				"in several ways" ),
 	"Tobias Doerffel <tobydox/at/users.sf.net>",
 	0x0100,
-	plugin::INSTRUMENT,
-	new QPixmap( PLUGIN_NAME::getIconPixmap( "logo" ) )
+	plugin::Instrument,
+	new QPixmap( PLUGIN_NAME::getIconPixmap( "logo" ) ),
+	NULL
 } ;
 
 }
 
  
 tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
-	instrument( _channel_track, &tripleoscillator_plugin_descriptor ),
-	m_modulationAlgo1( oscillator::MIX ),
-	m_modulationAlgo2( oscillator::MIX ),
-	m_modulationAlgo3( oscillator::MIX )
+	instrument( _channel_track, &tripleoscillator_plugin_descriptor )
 {
-	for( int i = 0; i < NUM_OF_OSCILLATORS; ++i )
-	{
-		m_osc[i].m_sampleBuffer = new sampleBuffer( eng() );
-	}
-
 #ifdef QT4
 	setAutoFillBackground( TRUE );
 	QPalette pal;
@@ -101,9 +94,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 	setErasePixmap( PLUGIN_NAME::getIconPixmap( "artwork" ) );
 #endif
 
-	pixmapButton * pm_osc1_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	pm_osc1_btn->move( 80, 50 );
+	pixmapButton * pm_osc1_btn = new pixmapButton( this, NULL, NULL );
+	pm_osc1_btn->move( 46, 50 );
 	pm_osc1_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 								"pm_active" ) );
 	pm_osc1_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -114,9 +106,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"modulating oscillator 2 with "
 					"oscillator 1" ) );
 
-	pixmapButton * am_osc1_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	am_osc1_btn->move( 120, 50 );
+	pixmapButton * am_osc1_btn = new pixmapButton( this, NULL, NULL );
+	am_osc1_btn->move( 86, 50 );
 	am_osc1_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 								"am_active" ) );
 	am_osc1_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -127,9 +118,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"modulating oscillator 2 with "
 					"oscillator 1" ) );
 
-	pixmapButton * mix_osc1_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	mix_osc1_btn->move( 160, 50 );
+	pixmapButton * mix_osc1_btn = new pixmapButton( this, NULL, NULL );
+	mix_osc1_btn->move( 126, 50 );
 	mix_osc1_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"mix_active" ) );
 	mix_osc1_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -138,9 +128,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"btn_mask" ).createHeuristicMask() ) );
 	toolTip::add( mix_osc1_btn, tr( "mix output of oscillator 1 & 2" ) );
 
-	pixmapButton * sync_osc1_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	sync_osc1_btn->move( 200, 50 );
+	pixmapButton * sync_osc1_btn = new pixmapButton( this, NULL, NULL );
+	sync_osc1_btn->move( 166, 50 );
 	sync_osc1_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"sync_active" ) );
 	sync_osc1_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -150,9 +139,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 	toolTip::add( sync_osc1_btn, tr( "synchronize oscillator 1 with "
 							"oscillator 2" ) );
 
-	pixmapButton * fm_osc1_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	fm_osc1_btn->move( 330, 50 );
+	pixmapButton * fm_osc1_btn = new pixmapButton( this, NULL, NULL );
+	fm_osc1_btn->move( 206, 50 );
 	fm_osc1_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 								"fm_active" ) );
 	fm_osc1_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -165,21 +153,20 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 
 	m_mod1BtnGrp = new automatableButtonGroup( this,
 						tr( "Modulation type 1" ),
-						eng(), _channel_track );
+						_channel_track );
 	m_mod1BtnGrp->addButton( pm_osc1_btn );
 	m_mod1BtnGrp->addButton( am_osc1_btn );
 	m_mod1BtnGrp->addButton( mix_osc1_btn );
 	m_mod1BtnGrp->addButton( sync_osc1_btn );
 	m_mod1BtnGrp->addButton( fm_osc1_btn );
-	m_mod1BtnGrp->setInitValue( m_modulationAlgo1 );
+	m_mod1BtnGrp->setInitValue( m_osc[0].m_modulationAlgo );
 
 	connect( m_mod1BtnGrp, SIGNAL( valueChanged( int ) ),
-						this, SLOT( mod1Ch( int ) ) );
+					&m_osc[0], SLOT( modCh( int ) ) );
 
 
-	pixmapButton * pm_osc2_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	pm_osc2_btn->move( 80, 70 );
+	pixmapButton * pm_osc2_btn = new pixmapButton( this, NULL, NULL );
+	pm_osc2_btn->move( 46, 68 );
 	pm_osc2_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 								"pm_active" ) );
 	pm_osc2_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -190,9 +177,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"modulating oscillator 3 with "
 					"oscillator 2" ) );
 
-	pixmapButton * am_osc2_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	am_osc2_btn->move( 120, 70 );
+	pixmapButton * am_osc2_btn = new pixmapButton( this, NULL, NULL );
+	am_osc2_btn->move( 86, 68 );
 	am_osc2_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 								"am_active" ) );
 	am_osc2_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -203,9 +189,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"modulating oscillator 3 with "
 					"oscillator 2" ) );
 
-	pixmapButton * mix_osc2_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	mix_osc2_btn->move( 160, 70 );
+	pixmapButton * mix_osc2_btn = new pixmapButton( this, NULL, NULL );
+	mix_osc2_btn->move( 126, 68 );
 	mix_osc2_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"mix_active" ) );
 	mix_osc2_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -214,9 +199,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"btn_mask" ).createHeuristicMask() ) );
 	toolTip::add( mix_osc2_btn, tr("mix output of oscillator 2 & 3" ) );
 
-	pixmapButton * sync_osc2_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	sync_osc2_btn->move( 200, 70 );
+	pixmapButton * sync_osc2_btn = new pixmapButton( this, NULL, NULL );
+	sync_osc2_btn->move( 166, 68 );
 	sync_osc2_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 							"sync_active" ) );
 	sync_osc2_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -226,9 +210,8 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 	toolTip::add( sync_osc2_btn, tr( "synchronize oscillator 2 with "
 							"oscillator 3" ) );
 
-	pixmapButton * fm_osc2_btn = new pixmapButton( this, NULL, eng(),
-									NULL );
-	fm_osc2_btn->move( 330, 70 );
+	pixmapButton * fm_osc2_btn = new pixmapButton( this, NULL, NULL );
+	fm_osc2_btn->move( 206, 68 );
 	fm_osc2_btn->setActiveGraphic( PLUGIN_NAME::getIconPixmap(
 								"fm_active" ) );
 	fm_osc2_btn->setInactiveGraphic( PLUGIN_NAME::getIconPixmap(
@@ -241,38 +224,33 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 
 	m_mod2BtnGrp = new automatableButtonGroup( this,
 						tr( "Modulation type 2" ),
-						eng(), _channel_track );
+						_channel_track );
 	m_mod2BtnGrp->addButton( pm_osc2_btn );
 	m_mod2BtnGrp->addButton( am_osc2_btn );
 	m_mod2BtnGrp->addButton( mix_osc2_btn );
 	m_mod2BtnGrp->addButton( sync_osc2_btn );
 	m_mod2BtnGrp->addButton( fm_osc2_btn );
-	m_mod2BtnGrp->setInitValue( m_modulationAlgo2 );
+	m_mod2BtnGrp->setInitValue( m_osc[1].m_modulationAlgo );
 
 	connect( m_mod2BtnGrp, SIGNAL( valueChanged( int ) ),
-						this, SLOT( mod2Ch( int ) ) );
+					&m_osc[1], SLOT( modCh( int ) ) );
 
 
 	for( int i = 0; i < NUM_OF_OSCILLATORS; ++i )
 	{
-		// reset current m_osc-structure
-		m_osc[i].waveShape = oscillator::SIN_WAVE;
-		
 		// setup volume-knob
-		m_osc[i].volKnob = new volumeKnob( knobSmall_17, this, tr(
-				"Osc %1 volume" ).arg( i+1 ), eng(),
-							_channel_track );
-		m_osc[i].volKnob->setData( i );
-		m_osc[i].volKnob->move( 6, 104+i*50 );
-		m_osc[i].volKnob->setRange( MIN_VOLUME, MAX_VOLUME, 1.0f );
-		m_osc[i].volKnob->setInitValue( DEFAULT_VOLUME
+		m_osc[i].m_volKnob = new volumeKnob( knobSmall_17, this, tr(
+				"Osc %1 volume" ).arg( i+1 ), _channel_track );
+		m_osc[i].m_volKnob->move( 6, 104 + i * 50 );
+		m_osc[i].m_volKnob->setRange( MIN_VOLUME, MAX_VOLUME, 1.0f );
+		m_osc[i].m_volKnob->setInitValue( DEFAULT_VOLUME
 							/ NUM_OF_OSCILLATORS );
-		m_osc[i].volKnob->setHintText( tr( "Osc %1 volume:" ).arg(
+		m_osc[i].m_volKnob->setHintText( tr( "Osc %1 volume:" ).arg(
 							i+1 ) + " ", "%" );
 #ifdef QT4
-		m_osc[i].volKnob->setWhatsThis(
+		m_osc[i].m_volKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].volKnob,
+		QWhatsThis::add( m_osc[i].m_volKnob,
 #endif
 			tr( "With this knob you can set the volume of "
 				"oscillator %1. When setting a value of 0 the "
@@ -281,19 +259,20 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				"here.").arg( i+1 ) );
 
 		// setup panning-knob
-		m_osc[i].panKnob = new knob( knobSmall_17, this,
-				tr( "Osc %1 panning" ).arg( i + 1 ), eng(),
+		m_osc[i].m_panKnob = new knob( knobSmall_17, this,
+				tr( "Osc %1 panning" ).arg( i + 1 ),
 							_channel_track );
-		m_osc[i].panKnob->setData( i );
-		m_osc[i].panKnob->move( 33, 104+i*50 );
-		m_osc[i].panKnob->setRange( PANNING_LEFT, PANNING_RIGHT, 1.0f );
-		m_osc[i].panKnob->setInitValue( DEFAULT_PANNING );
-		m_osc[i].panKnob->setHintText( tr("Osc %1 panning:").arg( i+1 )
+		m_osc[i].m_panKnob->move( 33, 104 + i * 50 );
+		m_osc[i].m_panKnob->setRange( PANNING_LEFT, PANNING_RIGHT,
+									1.0f );
+		m_osc[i].m_panKnob->setInitValue( DEFAULT_PANNING );
+		m_osc[i].m_panKnob->setHintText( tr("Osc %1 panning:").arg(
+									i + 1 )
 						+ " ", "" );
 #ifdef QT4
-		m_osc[i].panKnob->setWhatsThis(
+		m_osc[i].m_panKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].panKnob,
+		QWhatsThis::add( m_osc[i].m_panKnob,
 #endif
 			tr( "With this knob you can set the panning of the "
 				"oscillator %1. A value of -100 means 100% "
@@ -301,21 +280,20 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				"output right.").arg( i+1 ) );
 
 		// setup coarse-knob
-		m_osc[i].coarseKnob = new knob( knobSmall_17, this,
+		m_osc[i].m_coarseKnob = new knob( knobSmall_17, this,
 				tr( "Osc %1 coarse detuning" ).arg( i + 1 ),
-							eng(), _channel_track );
-		m_osc[i].coarseKnob->setData( i );
-		m_osc[i].coarseKnob->move( 66, 104 + i * 50 );
-		m_osc[i].coarseKnob->setRange( -2 * NOTES_PER_OCTAVE,
+							_channel_track );
+		m_osc[i].m_coarseKnob->move( 66, 104 + i * 50 );
+		m_osc[i].m_coarseKnob->setRange( -2 * NOTES_PER_OCTAVE,
 						2 * NOTES_PER_OCTAVE, 1.0f );
-		m_osc[i].coarseKnob->setInitValue( 0.0f );
-		m_osc[i].coarseKnob->setHintText( tr( "Osc %1 coarse detuning:"
-							).arg( i + 1 ) + " ",
+		m_osc[i].m_coarseKnob->setInitValue( 0.0f );
+		m_osc[i].m_coarseKnob->setHintText(
+			tr( "Osc %1 coarse detuning:" ).arg( i + 1 ) + " ",
 						" " + tr( "semitones" ) );
 #ifdef QT4
-		m_osc[i].coarseKnob->setWhatsThis(
+		m_osc[i].m_coarseKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].coarseKnob,
+		QWhatsThis::add( m_osc[i].m_coarseKnob,
 #endif
 			tr( "With this knob you can set the coarse detuning of "
 				"oscillator %1. You can detune the oscillator "
@@ -324,21 +302,20 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				arg( i + 1 ) );
 
 		// setup knob for left fine-detuning
-		m_osc[i].fineLKnob = new knob( knobSmall_17, this,
+		m_osc[i].m_fineLKnob = new knob( knobSmall_17, this,
 				tr( "Osc %1 fine detuning left" ).arg( i+1 ),
-							eng(), _channel_track );
-		m_osc[i].fineLKnob->setData( i );
-		m_osc[i].fineLKnob->move( 90, 104 + i * 50 );
-		m_osc[i].fineLKnob->setRange( -100.0f, 100.0f, 1.0f );
-		m_osc[i].fineLKnob->setInitValue( 0.0f );
-		m_osc[i].fineLKnob->setHintText( tr( "Osc %1 fine detuning "
+							_channel_track );
+		m_osc[i].m_fineLKnob->move( 90, 104 + i * 50 );
+		m_osc[i].m_fineLKnob->setRange( -100.0f, 100.0f, 1.0f );
+		m_osc[i].m_fineLKnob->setInitValue( 0.0f );
+		m_osc[i].m_fineLKnob->setHintText( tr( "Osc %1 fine detuning "
 							"left:" ).arg( i + 1 )
 							+ " ", " " +
 							tr( "cents" ) );
 #ifdef QT4
-		m_osc[i].fineLKnob->setWhatsThis(
+		m_osc[i].m_fineLKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].fineLKnob,
+		QWhatsThis::add( m_osc[i].m_fineLKnob,
 #endif
 			tr( "With this knob you can set the fine detuning of "
 				"oscillator %1 for the left channel. The fine-"
@@ -347,21 +324,20 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				"\"fat\" sounds." ).arg( i + 1 ) );
 
 		// setup knob for right fine-detuning
-		m_osc[i].fineRKnob = new knob( knobSmall_17, this,
+		m_osc[i].m_fineRKnob = new knob( knobSmall_17, this,
 						tr( "Osc %1 fine detuning right"
 							).arg( i + 1 ),
-							eng(), _channel_track );
-		m_osc[i].fineRKnob->setData( i );
-		m_osc[i].fineRKnob->move( 110, 104 + i * 50 );
-		m_osc[i].fineRKnob->setRange( -100.0f, 100.0f, 1.0f );
-		m_osc[i].fineRKnob->setInitValue( 0.0f );
-		m_osc[i].fineRKnob->setHintText( tr( "Osc %1 fine detuning "
+							_channel_track );
+		m_osc[i].m_fineRKnob->move( 110, 104 + i * 50 );
+		m_osc[i].m_fineRKnob->setRange( -100.0f, 100.0f, 1.0f );
+		m_osc[i].m_fineRKnob->setInitValue( 0.0f );
+		m_osc[i].m_fineRKnob->setHintText( tr( "Osc %1 fine detuning "
 							"right:").arg( i + 1 ) +
 						" ", " " + tr( "cents" ) );
 #ifdef QT4
-		m_osc[i].fineRKnob->setWhatsThis(
+		m_osc[i].m_fineRKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].fineRKnob,
+		QWhatsThis::add( m_osc[i].m_fineRKnob,
 #endif
 			tr( "With this knob you can set the fine detuning of "
 				"oscillator %1 for the right channel. The "
@@ -370,23 +346,21 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				"\"fat\" sounds." ).arg( i+1 ) );
 
 		// setup phase-offset-knob
-		m_osc[i].phaseOffsetKnob = new knob( knobSmall_17, this,
+		m_osc[i].m_phaseOffsetKnob = new knob( knobSmall_17, this,
 							tr( "Osc %1 phase-"
 							"offset" ).arg( i+1 ),
-							eng(),
 							_channel_track );
-		m_osc[i].phaseOffsetKnob->setData( i );
-		m_osc[i].phaseOffsetKnob->move( 142, 104 + i * 50 );
-		m_osc[i].phaseOffsetKnob->setRange( 0.0f, 360.0f, 1.0f );
-		m_osc[i].phaseOffsetKnob->setInitValue( 0.0f );
-		m_osc[i].phaseOffsetKnob->setHintText( tr( "Osc %1 phase-"
+		m_osc[i].m_phaseOffsetKnob->move( 142, 104 + i * 50 );
+		m_osc[i].m_phaseOffsetKnob->setRange( 0.0f, 360.0f, 1.0f );
+		m_osc[i].m_phaseOffsetKnob->setInitValue( 0.0f );
+		m_osc[i].m_phaseOffsetKnob->setHintText( tr( "Osc %1 phase-"
 								"offset:" ).
 								arg( i + 1 ) +
 						" ", " " + tr( "degrees" ) );
 #ifdef QT4
-		m_osc[i].phaseOffsetKnob->setWhatsThis(
+		m_osc[i].m_phaseOffsetKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].phaseOffsetKnob,
+		QWhatsThis::add( m_osc[i].m_phaseOffsetKnob,
 #endif
 			tr( "With this knob you can set the phase-offset of "
 				"oscillator %1. That means you can move the "
@@ -398,26 +372,24 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				).arg( i+1 ) );
 
 		// setup stereo-phase-detuning-knob
-		m_osc[i].stereoPhaseDetuningKnob = new knob( knobSmall_17, this,
-						tr( "Osc %1 stereo phase-"
+		m_osc[i].m_stereoPhaseDetuningKnob = new knob( knobSmall_17,
+						this, tr( "Osc %1 stereo phase-"
 							"detuning" ).arg( i+1 ),
-							eng(),
 							_channel_track );
-		m_osc[i].stereoPhaseDetuningKnob->setData( i );
-		m_osc[i].stereoPhaseDetuningKnob->move( 166, 104 + i * 50 );
-		m_osc[i].stereoPhaseDetuningKnob->setRange( 0.0f, 360.0f,
+		m_osc[i].m_stereoPhaseDetuningKnob->move( 166, 104 + i * 50 );
+		m_osc[i].m_stereoPhaseDetuningKnob->setRange( 0.0f, 360.0f,
 									1.0f );
-		m_osc[i].stereoPhaseDetuningKnob->setInitValue( 0.0f );
-		m_osc[i].stereoPhaseDetuningKnob->setHintText( tr("Osc %1 "
+		m_osc[i].m_stereoPhaseDetuningKnob->setInitValue( 0.0f );
+		m_osc[i].m_stereoPhaseDetuningKnob->setHintText( tr("Osc %1 "
 								"stereo phase-"
 								"detuning:" ).
 								arg( i + 1 ) +
 								" ", " " +
 							tr( "degrees" ) );
 #ifdef QT4
-		m_osc[i].stereoPhaseDetuningKnob->setWhatsThis(
+		m_osc[i].m_stereoPhaseDetuningKnob->setWhatsThis(
 #else
-		QWhatsThis::add( m_osc[i].stereoPhaseDetuningKnob,
+		QWhatsThis::add( m_osc[i].m_stereoPhaseDetuningKnob,
 #endif
 			tr( "With this knob you can set the stereo phase-"
 				"detuning of oscillator %1. The stereo phase-"
@@ -427,46 +399,35 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				"stereo-sounds." ).arg( i+1 ) );
 
 		// Connect knobs with oscillators' inputs
-		connect( m_osc[i].volKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this, SLOT( updateVolume( const QVariant & ) ) );
-		connect( m_osc[i].panKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this, SLOT( updateVolume( const QVariant & ) ) );
-		updateVolume( i );
+		connect( m_osc[i].m_volKnob, SIGNAL( valueChanged() ),
+					&m_osc[i], SLOT( updateVolume() ) );
+		connect( m_osc[i].m_panKnob, SIGNAL( valueChanged() ),
+					&m_osc[i], SLOT( updateVolume() ) );
+		m_osc[i].updateVolume();
 
-		connect( m_osc[i].coarseKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this, SLOT( updateDetuningLeft( const QVariant & ) ) );
-		connect( m_osc[i].coarseKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this, SLOT( updateDetuningRight( const QVariant & ) ) );
-		connect( m_osc[i].fineLKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this, SLOT( updateDetuningLeft( const QVariant & ) ) );
-		connect( m_osc[i].fineRKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this, SLOT( updateDetuningRight( const QVariant & ) ) );
-		updateDetuningLeft( i );
-		updateDetuningRight( i );
+		connect( m_osc[i].m_coarseKnob, SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updateDetuningLeft() ) );
+		connect( m_osc[i].m_coarseKnob, SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updateDetuningRight() ) );
+		connect( m_osc[i].m_fineLKnob, SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updateDetuningLeft() ) );
+		connect( m_osc[i].m_fineRKnob, SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updateDetuningRight() ) );
+		m_osc[i].updateDetuningLeft();
+		m_osc[i].updateDetuningRight();
 
-		connect( m_osc[i].phaseOffsetKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this,
-			SLOT( updatePhaseOffsetLeft( const QVariant & ) ) );
-		connect( m_osc[i].phaseOffsetKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this,
-			SLOT( updatePhaseOffsetRight( const QVariant & ) ) );
-		connect( m_osc[i].stereoPhaseDetuningKnob,
-				SIGNAL( valueChanged( const QVariant & ) ),
-			this,
-			SLOT( updatePhaseOffsetLeft( const QVariant & ) ) );
-		updatePhaseOffsetLeft( i );
-		updatePhaseOffsetRight( i );
+		connect( m_osc[i].m_phaseOffsetKnob, SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updatePhaseOffsetLeft() ) );
+		connect( m_osc[i].m_phaseOffsetKnob, SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updatePhaseOffsetRight() ) );
+		connect( m_osc[i].m_stereoPhaseDetuningKnob,
+						SIGNAL( valueChanged() ),
+				&m_osc[i], SLOT( updatePhaseOffsetLeft() ) );
+		m_osc[i].updatePhaseOffsetLeft();
+		m_osc[i].updatePhaseOffsetRight();
 
 		pixmapButton * sin_wave_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		sin_wave_btn->move( 188, 105 + i * 50 );
 		sin_wave_btn->setActiveGraphic( embed::getIconPixmap(
 							"sin_wave_active" ) );
@@ -478,7 +439,7 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 						"current oscillator." ) );
 
 		pixmapButton * triangle_wave_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		triangle_wave_btn->move( 203, 105 + i * 50 );
 		triangle_wave_btn->setActiveGraphic(
 			embed::getIconPixmap( "triangle_wave_active" ) );
@@ -489,7 +450,7 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 						"for current oscillator." ) );
 
 		pixmapButton * saw_wave_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		saw_wave_btn->move( 218, 105 + i * 50 );
 		saw_wave_btn->setActiveGraphic( embed::getIconPixmap(
 							"saw_wave_active" ) );
@@ -500,7 +461,7 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 						"current oscillator." ) );
 
 		pixmapButton * sqr_wave_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		sqr_wave_btn->move( 233, 105 + i * 50 );
 		sqr_wave_btn->setActiveGraphic( embed::getIconPixmap(
 						"square_wave_active" ) );
@@ -511,7 +472,7 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 						"current oscillator." ) );
 
 		pixmapButton * moog_saw_wave_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		moog_saw_wave_btn->move( 188, 120+i*50 );
 		moog_saw_wave_btn->setActiveGraphic(
 			embed::getIconPixmap( "moog_saw_wave_active" ) );
@@ -522,7 +483,7 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 						"for current oscillator." ) );
 
 		pixmapButton * exp_wave_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		exp_wave_btn->move( 203, 120+i*50 );
 		exp_wave_btn->setActiveGraphic( embed::getIconPixmap(
 							"exp_wave_active" ) );
@@ -533,7 +494,7 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 					"wave for current oscillator." ) );
 
 		pixmapButton * white_noise_btn = new pixmapButton( this, NULL,
-								eng(), NULL );
+									NULL );
 		white_noise_btn->move( 218, 120+i*50 );
 		white_noise_btn->setActiveGraphic(
 			embed::getIconPixmap( "white_noise_wave_active" ) );
@@ -543,59 +504,35 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 				tr( "Click here if you want a white-noise for "
 						"current oscillator." ) );
 
-		m_osc[i].usrWaveBtn = new pixmapButton( this, NULL, eng(),
-									NULL );
-		m_osc[i].usrWaveBtn->move( 233, 120+i*50 );
-		m_osc[i].usrWaveBtn->setActiveGraphic( embed::getIconPixmap(
+		m_osc[i].m_usrWaveBtn = new pixmapButton( this, NULL, NULL );
+		m_osc[i].m_usrWaveBtn->move( 233, 120+i*50 );
+		m_osc[i].m_usrWaveBtn->setActiveGraphic( embed::getIconPixmap(
 							"usr_wave_active" ) );
-		m_osc[i].usrWaveBtn->setInactiveGraphic( embed::getIconPixmap(
+		m_osc[i].m_usrWaveBtn->setInactiveGraphic( embed::getIconPixmap(
 							"usr_wave_inactive" ) );
-		toolTip::add( m_osc[i].usrWaveBtn,
+		toolTip::add( m_osc[i].m_usrWaveBtn,
 				tr( "Click here if you want a user-defined "
 				"wave-shape for current oscillator." ) );
 
-		m_osc[i].waveBtnGrp = new automatableButtonGroup( this,
+		m_osc[i].m_waveBtnGrp = new automatableButtonGroup( this,
 					tr( "Osc %1 wave shape" ).arg( i + 1 ),
-					eng(), _channel_track );
-		m_osc[i].waveBtnGrp->addButton( sin_wave_btn );
-		m_osc[i].waveBtnGrp->addButton( triangle_wave_btn );
-		m_osc[i].waveBtnGrp->addButton( saw_wave_btn );
-		m_osc[i].waveBtnGrp->addButton( sqr_wave_btn );
-		m_osc[i].waveBtnGrp->addButton( moog_saw_wave_btn );
-		m_osc[i].waveBtnGrp->addButton( exp_wave_btn );
-		m_osc[i].waveBtnGrp->addButton( white_noise_btn );
-		m_osc[i].waveBtnGrp->addButton( m_osc[i].usrWaveBtn );
+					_channel_track );
+		m_osc[i].m_waveBtnGrp->addButton( sin_wave_btn );
+		m_osc[i].m_waveBtnGrp->addButton( triangle_wave_btn );
+		m_osc[i].m_waveBtnGrp->addButton( saw_wave_btn );
+		m_osc[i].m_waveBtnGrp->addButton( sqr_wave_btn );
+		m_osc[i].m_waveBtnGrp->addButton( moog_saw_wave_btn );
+		m_osc[i].m_waveBtnGrp->addButton( exp_wave_btn );
+		m_osc[i].m_waveBtnGrp->addButton( white_noise_btn );
+		m_osc[i].m_waveBtnGrp->addButton( m_osc[i].m_usrWaveBtn );
 
-		if( i == 0 )
-		{
-			connect( m_osc[i].waveBtnGrp,
-						SIGNAL( valueChanged( int ) ),
-				this, SLOT( osc0WaveCh( int ) ) );
-			connect( m_osc[i].usrWaveBtn,
-					SIGNAL( doubleClicked() ), this,
-					SLOT( osc0UserDefWaveDblClick() ) );
-		}
-		else if( i == 1 )
-		{
-			connect( m_osc[i].waveBtnGrp,
-						SIGNAL( valueChanged( int ) ),
-				this, SLOT( osc1WaveCh( int ) ) );
-			connect( m_osc[i].usrWaveBtn,
-					SIGNAL( doubleClicked() ), this,
-					SLOT( osc1UserDefWaveDblClick() ) );
-		}
-		else if( i == 2 )
-		{
-			connect( m_osc[i].waveBtnGrp,
-						SIGNAL( valueChanged( int ) ),
-				this, SLOT( osc2WaveCh( int ) ) );
-			connect( m_osc[i].usrWaveBtn,
-					SIGNAL( doubleClicked() ), this,
-					SLOT( osc2UserDefWaveDblClick() ) );
-		}
+		connect( m_osc[i].m_waveBtnGrp, SIGNAL( valueChanged( int ) ),
+					&m_osc[i], SLOT( oscWaveCh( int ) ) );
+		connect( m_osc[i].m_usrWaveBtn, SIGNAL( doubleClicked() ),
+				&m_osc[i], SLOT( oscUserDefWaveDblClick() ) );
 	}
 
-	connect( eng()->getMixer(), SIGNAL( sampleRateChanged() ),
+	connect( engine::getMixer(), SIGNAL( sampleRateChanged() ),
 			this, SLOT( updateAllDetuning() ) );
 }
 
@@ -604,10 +541,6 @@ tripleOscillator::tripleOscillator( instrumentTrack * _channel_track ) :
 
 tripleOscillator::~tripleOscillator()
 {
-	for( int i = 0; i < NUM_OF_OSCILLATORS; ++i )
-	{
-		delete m_osc[i].m_sampleBuffer;
-	}
 }
 
 
@@ -621,16 +554,17 @@ void tripleOscillator::saveSettings( QDomDocument & _doc, QDomElement & _this )
 	for( int i = 0; i < NUM_OF_OSCILLATORS; ++i )
 	{
 		QString is = QString::number( i );
-		m_osc[i].volKnob->saveSettings( _doc, _this, "vol" + is );
-		m_osc[i].panKnob->saveSettings( _doc, _this, "pan" + is );
-		m_osc[i].coarseKnob->saveSettings( _doc, _this, "coarse" + is );
-		m_osc[i].fineLKnob->saveSettings( _doc, _this, "finel" + is );
-		m_osc[i].fineRKnob->saveSettings( _doc, _this, "finer" + is );
-		m_osc[i].phaseOffsetKnob->saveSettings( _doc, _this,
+		m_osc[i].m_volKnob->saveSettings( _doc, _this, "vol" + is );
+		m_osc[i].m_panKnob->saveSettings( _doc, _this, "pan" + is );
+		m_osc[i].m_coarseKnob->saveSettings( _doc, _this, "coarse"
+									+ is );
+		m_osc[i].m_fineLKnob->saveSettings( _doc, _this, "finel" + is );
+		m_osc[i].m_fineRKnob->saveSettings( _doc, _this, "finer" + is );
+		m_osc[i].m_phaseOffsetKnob->saveSettings( _doc, _this,
 							"phoffset" + is );
-		m_osc[i].stereoPhaseDetuningKnob->saveSettings( _doc, _this,
+		m_osc[i].m_stereoPhaseDetuningKnob->saveSettings( _doc, _this,
 							"stphdetun" + is );
-		m_osc[i].waveBtnGrp->saveSettings( _doc, _this,
+		m_osc[i].m_waveBtnGrp->saveSettings( _doc, _this,
 							"wavetype" + is );
 		_this.setAttribute( "userwavefile" + is,
 					m_osc[i].m_sampleBuffer->audioFile() );
@@ -648,18 +582,18 @@ void tripleOscillator::loadSettings( const QDomElement & _this )
 	for( int i = 0; i < NUM_OF_OSCILLATORS; ++i )
 	{
 		QString is = QString::number( i );
-		m_osc[i].volKnob->loadSettings( _this, "vol" + is );
-		m_osc[i].panKnob->loadSettings( _this, "pan" + is );
-		m_osc[i].coarseKnob->loadSettings( _this, "coarse" + is );
-		m_osc[i].fineLKnob->loadSettings( _this, "finel" + is );
-		m_osc[i].fineRKnob->loadSettings( _this, "finer" + is );
-		m_osc[i].phaseOffsetKnob->loadSettings( _this,
+		m_osc[i].m_volKnob->loadSettings( _this, "vol" + is );
+		m_osc[i].m_panKnob->loadSettings( _this, "pan" + is );
+		m_osc[i].m_coarseKnob->loadSettings( _this, "coarse" + is );
+		m_osc[i].m_fineLKnob->loadSettings( _this, "finel" + is );
+		m_osc[i].m_fineRKnob->loadSettings( _this, "finer" + is );
+		m_osc[i].m_phaseOffsetKnob->loadSettings( _this,
 							"phoffset" + is );
-		m_osc[i].stereoPhaseDetuningKnob->loadSettings( _this,
+		m_osc[i].m_stereoPhaseDetuningKnob->loadSettings( _this,
 							"stphdetun" + is );
 		m_osc[i].m_sampleBuffer->setAudioFile( _this.attribute(
 							"userwavefile" + is ) );
-		m_osc[i].waveBtnGrp->loadSettings( _this, "wavetype" + is );
+		m_osc[i].m_waveBtnGrp->loadSettings( _this, "wavetype" + is );
 	}
 }
 
@@ -689,52 +623,52 @@ QString tripleOscillator::nodeName( void ) const
 
 
 
-void tripleOscillator::playNote( notePlayHandle * _n )
+void tripleOscillator::playNote( notePlayHandle * _n, bool )
 {
-	if( _n->totalFramesPlayed() == 0 )
+	if( _n->totalFramesPlayed() == 0 || _n->m_pluginData == NULL )
 	{
 		oscillator * oscs_l[NUM_OF_OSCILLATORS];
 		oscillator * oscs_r[NUM_OF_OSCILLATORS];
 
-		for( Sint8 i = NUM_OF_OSCILLATORS-1; i >= 0; --i )
+		for( Sint8 i = NUM_OF_OSCILLATORS - 1; i >= 0; --i )
 		{
 
-			// the third oscs needs no sub-oscs...
-			if( i == 2 )
+			// the last oscs needs no sub-oscs...
+			if( i == NUM_OF_OSCILLATORS - 1 )
 			{
 				oscs_l[i] = new oscillator(
-						&m_osc[i].waveShape,
-						&m_modulationAlgo3,
-						&_n->m_frequency,
-						&m_osc[i].detuningLeft,
-						&m_osc[i].phaseOffsetLeft,
-						&m_osc[i].volumeLeft );
+						m_osc[i].m_waveShape,
+						m_osc[i].m_modulationAlgo,
+						_n->frequency(),
+						m_osc[i].m_detuningLeft,
+						m_osc[i].m_phaseOffsetLeft,
+						m_osc[i].m_volumeLeft );
 				oscs_r[i] = new oscillator(
-						&m_osc[i].waveShape,
-						&m_modulationAlgo3,
-						&_n->m_frequency,
-						&m_osc[i].detuningRight,
-						&m_osc[i].phaseOffsetRight,
-						&m_osc[i].volumeRight );
+						m_osc[i].m_waveShape,
+						m_osc[i].m_modulationAlgo,
+						_n->frequency(),
+						m_osc[i].m_detuningRight,
+						m_osc[i].m_phaseOffsetRight,
+						m_osc[i].m_volumeRight );
 			}
 			else
 			{
 				oscs_l[i] = new oscillator(
-						&m_osc[i].waveShape,
-						getModulationAlgo( i + 1 ),
-						&_n->m_frequency,
-						&m_osc[i].detuningLeft,
-						&m_osc[i].phaseOffsetLeft,
-						&m_osc[i].volumeLeft,
-							oscs_l[i + 1] );
+						m_osc[i].m_waveShape,
+						m_osc[i].m_modulationAlgo,
+						_n->frequency(),
+						m_osc[i].m_detuningLeft,
+						m_osc[i].m_phaseOffsetLeft,
+						m_osc[i].m_volumeLeft,
+						oscs_l[i + 1] );
 				oscs_r[i] = new oscillator(
-						&m_osc[i].waveShape,
-						getModulationAlgo( i + 1 ),
-						&_n->m_frequency,
-						&m_osc[i].detuningRight,
-						&m_osc[i].phaseOffsetRight,
-						&m_osc[i].volumeRight,
-								oscs_r[i + 1] );
+						m_osc[i].m_waveShape,
+						m_osc[i].m_modulationAlgo,
+						_n->frequency(),
+						m_osc[i].m_detuningRight,
+						m_osc[i].m_phaseOffsetRight,
+						m_osc[i].m_volumeRight,
+						oscs_r[i + 1] );
 			}
 
 			oscs_l[i]->setUserWave( m_osc[i].m_sampleBuffer );
@@ -752,15 +686,17 @@ void tripleOscillator::playNote( notePlayHandle * _n )
 	oscillator * osc_r = static_cast<oscPtr *>( _n->m_pluginData
 								)->oscRight;
 
-	const fpab_t frames = eng()->getMixer()->framesPerAudioBuffer();
-	sampleFrame * buf = bufferAllocator::alloc<sampleFrame>( frames );
+	const fpp_t frames = _n->framesLeftForCurrentPeriod();
+	sampleFrame * buf = new sampleFrame[frames];
 	
 	osc_l->update( buf, frames, 0 );
 	osc_r->update( buf, frames, 1 );
 
+	applyRelease( buf, _n );
+
 	getInstrumentTrack()->processAudioBuffer( buf, frames, _n );
 
-	bufferAllocator::free( buf );
+	delete[] buf;
 }
 
 
@@ -768,10 +704,6 @@ void tripleOscillator::playNote( notePlayHandle * _n )
 
 void tripleOscillator::deleteNotePluginData( notePlayHandle * _n )
 {
-	if( _n->m_pluginData == NULL )
-	{
-		return;
-	}
 	delete static_cast<oscillator *>( static_cast<oscPtr *>(
 						_n->m_pluginData )->oscLeft );
 	delete static_cast<oscillator *>( static_cast<oscPtr *>(
@@ -782,185 +714,127 @@ void tripleOscillator::deleteNotePluginData( notePlayHandle * _n )
 
 
 
-void tripleOscillator::osc0WaveCh( int _n )
-{
-	m_osc[0].waveShape = static_cast<oscillator::waveShapes>( _n );
-}
-
-
-
-
-void tripleOscillator::osc1WaveCh( int _n )
-{
-	m_osc[1].waveShape = static_cast<oscillator::waveShapes>( _n );
-}
-
-
-
-
-void tripleOscillator::osc2WaveCh( int _n )
-{
-	m_osc[2].waveShape = static_cast<oscillator::waveShapes>( _n );
-}
-
-
-
-
-void tripleOscillator::mod1Ch( int _n )
-{
-	m_modulationAlgo1 = static_cast<oscillator::modulationAlgos>( _n );
-}
-
-
-
-
-void tripleOscillator::mod2Ch( int _n )
-{
-	m_modulationAlgo2 = static_cast<oscillator::modulationAlgos>( _n );
-}
-
-
-
-
-void tripleOscillator::osc0UserDefWaveDblClick( void )
-{
-	QString af = m_osc[0].m_sampleBuffer->openAudioFile();
-	if( af != "" )
-	{
-		m_osc[0].m_sampleBuffer->setAudioFile( af );
-		toolTip::add( m_osc[0].usrWaveBtn,
-					m_osc[0].m_sampleBuffer->audioFile() );
-	}
-}
-
-
-
-void tripleOscillator::osc1UserDefWaveDblClick( void )
-{
-	QString af = m_osc[1].m_sampleBuffer->openAudioFile();
-	if( af != "" )
-	{
-		m_osc[1].m_sampleBuffer->setAudioFile( af );
-		toolTip::add( m_osc[1].usrWaveBtn,
-					m_osc[1].m_sampleBuffer->audioFile() );
-	}
-}
-
-
-
-void tripleOscillator::osc2UserDefWaveDblClick( void )
-{
-	QString af = m_osc[2].m_sampleBuffer->openAudioFile();
-	if( af != "" )
-	{
-		m_osc[2].m_sampleBuffer->setAudioFile( af );
-		toolTip::add( m_osc[2].usrWaveBtn,
-					m_osc[2].m_sampleBuffer->audioFile() );
-	}
-}
-
-
-
-
-void tripleOscillator::updateVolume( const QVariant & _data )
-{
-	const int _i = _data.toInt();
-	float panningFactorLeft;
-	float panningFactorRight;
-
-	if( m_osc[_i].panKnob->value() >= 0.0f )
-	{
-		panningFactorLeft = 1.0f - m_osc[_i].panKnob->value()
-						/ (float)PANNING_RIGHT;
-		panningFactorRight = 1.0f;
-	}
-	else
-	{
-		panningFactorLeft = 1.0f;
-		panningFactorRight = 1.0f + m_osc[_i].panKnob->value()
-						/ (float)PANNING_RIGHT;
-	}
-
-	m_osc[_i].volumeLeft = panningFactorLeft * m_osc[_i].volKnob->value()
-								/ 100.0f;
-	m_osc[_i].volumeRight = panningFactorRight * m_osc[_i].volKnob->value()
-								/ 100.0f;
-}
-
-
-
-
-void tripleOscillator::updateDetuningLeft( const QVariant & _data )
-{
-	const int _i = _data.toInt();
-	m_osc[_i].detuningLeft = powf( 2.0f, (
-			(float)m_osc[_i].coarseKnob->value() * 100.0f +
-			(float)m_osc[_i].fineLKnob->value() ) / 1200.0f )
-			/ static_cast<float>( eng()->getMixer()->sampleRate() );
-}
-
-
-
-
-void tripleOscillator::updateDetuningRight( const QVariant & _data )
-{
-	const int _i = _data.toInt();
-	m_osc[_i].detuningRight = powf( 2.0f, (
-			(float)m_osc[_i].coarseKnob->value() * 100.0f +
-			(float)m_osc[_i].fineRKnob->value() ) / 1200.0f )
-			/ static_cast<float>( eng()->getMixer()->sampleRate() );
-}
-
-
-
-
 void tripleOscillator::updateAllDetuning( void )
 {
 	for( int i = 0; i < NUM_OF_OSCILLATORS; ++i )
 	{
-		updateDetuningLeft( i );
-		updateDetuningRight( i );
+		m_osc[i].updateDetuningLeft();
+		m_osc[i].updateDetuningRight();
 	}
 }
 
 
 
 
-void tripleOscillator::updatePhaseOffsetLeft( const QVariant & _data )
+
+
+
+
+oscillatorObject::oscillatorObject( void ) :
+	m_waveShape( oscillator::SIN_WAVE ),
+	m_sampleBuffer( new sampleBuffer ),
+	m_modulationAlgo( oscillator::MIX )
 {
-	const int _i = _data.toInt();
-	m_osc[_i].phaseOffsetLeft = ( m_osc[_i].phaseOffsetKnob->value() +
-			m_osc[_i].stereoPhaseDetuningKnob->value() ) / 360.0f;
 }
 
 
 
 
-void tripleOscillator::updatePhaseOffsetRight( const QVariant & _data )
+oscillatorObject::~oscillatorObject()
 {
-	const int _i = _data.toInt();
-	m_osc[_i].phaseOffsetRight = m_osc[_i].phaseOffsetKnob->value()
-								/ 360.0f;
+	sharedObject::unref( m_sampleBuffer );
 }
 
 
 
 
-oscillator::modulationAlgos * tripleOscillator::getModulationAlgo( int _n )
+void oscillatorObject::oscWaveCh( int _n )
 {
-	if( _n == 1 )
+	m_waveShape = static_cast<oscillator::waveShapes>( _n );
+}
+
+
+
+
+void oscillatorObject::oscUserDefWaveDblClick( void )
+{
+	QString af = m_sampleBuffer->openAudioFile();
+	if( af != "" )
 	{
-		return( &m_modulationAlgo1 );
+		m_sampleBuffer->setAudioFile( af );
+		toolTip::add( m_usrWaveBtn, m_sampleBuffer->audioFile() );
+	}
+}
+
+
+
+
+void oscillatorObject::modCh( int _n )
+{
+	m_modulationAlgo = static_cast<oscillator::modulationAlgos>( _n );
+}
+
+
+
+
+void oscillatorObject::updateVolume( void )
+{
+	if( m_panKnob->value() >= 0.0f )
+	{
+		float panningFactorLeft = 1.0f - m_panKnob->value()
+							/ (float)PANNING_RIGHT;
+		m_volumeLeft = panningFactorLeft * m_volKnob->value() / 100.0f;
+		m_volumeRight = m_volKnob->value() / 100.0f;
 	}
 	else
 	{
-		return( &m_modulationAlgo2 );
+		m_volumeLeft = m_volKnob->value() / 100.0f;
+		float panningFactorRight = 1.0f + m_panKnob->value()
+							/ (float)PANNING_RIGHT;
+		m_volumeRight = panningFactorRight * m_volKnob->value()
+								/ 100.0f;
 	}
 }
 
 
 
 
+void oscillatorObject::updateDetuningLeft( void )
+{
+	m_detuningLeft = powf( 2.0f, ( (float)m_coarseKnob->value() * 100.0f
+				+ (float)m_fineLKnob->value() ) / 1200.0f )
+					/ engine::getMixer()->sampleRate();
+}
+
+
+
+
+void oscillatorObject::updateDetuningRight( void )
+{
+	m_detuningRight = powf( 2.0f, ( (float)m_coarseKnob->value() * 100.0f
+				+ (float)m_fineRKnob->value() ) / 1200.0f )
+					/ engine::getMixer()->sampleRate();
+}
+
+
+
+
+void oscillatorObject::updatePhaseOffsetLeft( void )
+{
+	m_phaseOffsetLeft = ( m_phaseOffsetKnob->value() +
+				m_stereoPhaseDetuningKnob->value() ) / 360.0f;
+}
+
+
+
+
+void oscillatorObject::updatePhaseOffsetRight( void )
+{
+	m_phaseOffsetRight = m_phaseOffsetKnob->value() / 360.0f;
+}
+
+
+
 
 extern "C"
 {
