@@ -1,7 +1,7 @@
 /*
  * vestige.h - instrument VeSTige for hosting VST-plugins
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -26,10 +26,8 @@
 #ifndef _VESTIGE_H
 #define _VESTIGE_H
 
-#include "instrument.h"
-#include "midi.h"
 
-#ifdef QT4
+#ifndef QT3
 
 #include <QtCore/QMutex>
 
@@ -40,6 +38,9 @@
 #endif
 
 
+#include "instrument.h"
+#include "midi.h"
+#include "note.h"
 #include "spc_bg_hndl_widget.h"
 
 
@@ -56,9 +57,10 @@ public:
 	vestigeInstrument( instrumentTrack * _channel_track );
 	virtual ~vestigeInstrument();
 
-	virtual void play( void );
+	virtual void play( bool _try_parallelizing );
 
-	virtual void FASTCALL playNote( notePlayHandle * _n );
+	virtual void FASTCALL playNote( notePlayHandle * _n,
+						bool _try_parallelizing );
 	virtual void FASTCALL deleteNotePluginData( notePlayHandle * _n );
 
 
@@ -71,12 +73,26 @@ public:
 	virtual void FASTCALL setParameter( const QString & _param,
 						const QString & _value );
 
+	virtual bool supportsParallelizing( void ) const
+	{
+		return( TRUE );
+	}
+
+	virtual void waitForWorkerThread( void );
+
+	virtual bool notePlayHandleBased( void ) const
+	{
+		return( FALSE );
+	}
+
+	virtual bool handleMidiEvent( const midiEvent & _me,
+						const midiTime & _time );
+
 
 protected slots:
 	void openPlugin( void );
 	void toggleGUI( void );
 	void noteOffAll( void );
-	void changeTempo( bpm_t _new_tempo );
 
 
 protected:
@@ -88,6 +104,14 @@ private:
 
 	static QPixmap * s_artwork;
 
+	enum states
+	{
+		OFF,
+		ON,
+		IGNORE_NEXT_NOTEOFF
+	} ;
+	states m_noteStates[NOTES];
+
 
 	remoteVSTPlugin * m_plugin;
 	QMutex m_pluginMutex;
