@@ -3,7 +3,7 @@
 /*
  * audio_port.cpp - base-class for objects providing sound at a port
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -19,33 +19,37 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
+#include "mixer.h"
+#include "audio_device.h"
+#include "config_mgr.h"
 
 #include "audio_port.h"
 #include "audio_device.h"
-#include "buffer_allocator.h"
+#include "engine.h"
 
 
-audioPort::audioPort( const QString & _name, engine * _engine ) :
-	engineObject( _engine ),
+audioPort::audioPort( const QString & _name ) :
 	m_bufferUsage( NONE ),
-	m_firstBuffer( bufferAllocator::alloc<surroundSampleFrame>(
-				eng()->getMixer()->framesPerAudioBuffer() ) ),
-	m_secondBuffer( bufferAllocator::alloc<surroundSampleFrame>(
-				eng()->getMixer()->framesPerAudioBuffer() ) ),
+	m_firstBuffer( new surroundSampleFrame[
+				engine::getMixer()->framesPerPeriod()] ),
+	m_secondBuffer( new surroundSampleFrame[
+				engine::getMixer()->framesPerPeriod()] ),
 	m_extOutputEnabled( FALSE ),
 	m_nextFxChannel( -1 ),
-	m_name( "unnamed port" )
+	m_name( "unnamed port" ),
+	m_effects( new effectChain ),
+	m_frames( engine::getMixer()->framesPerPeriod() )
 {
-	eng()->getMixer()->clearAudioBuffer( m_firstBuffer,
-				eng()->getMixer()->framesPerAudioBuffer() );
-	eng()->getMixer()->clearAudioBuffer( m_secondBuffer,
-				eng()->getMixer()->framesPerAudioBuffer() );
-	eng()->getMixer()->addAudioPort( this );
+	engine::getMixer()->clearAudioBuffer( m_firstBuffer,
+				engine::getMixer()->framesPerPeriod() );
+	engine::getMixer()->clearAudioBuffer( m_secondBuffer,
+				engine::getMixer()->framesPerPeriod() );
+	engine::getMixer()->addAudioPort( this );
 	setExtOutputEnabled( TRUE );
 }
 
@@ -54,13 +58,11 @@ audioPort::audioPort( const QString & _name, engine * _engine ) :
 
 audioPort::~audioPort()
 {
-	eng()->getMixer()->removeAudioPort( this );
-	if( m_extOutputEnabled == TRUE )
-	{
-		eng()->getMixer()->audioDev()->unregisterPort( this );
-	}
-	bufferAllocator::free( m_firstBuffer );
-	bufferAllocator::free( m_secondBuffer );
+	setExtOutputEnabled( FALSE );
+	engine::getMixer()->removeAudioPort( this );
+	delete[] m_firstBuffer;
+	delete[] m_secondBuffer;
+	delete m_effects;
 }
 
 
@@ -68,8 +70,8 @@ audioPort::~audioPort()
 
 void audioPort::nextPeriod( void )
 {
-	eng()->getMixer()->clearAudioBuffer( m_firstBuffer,
-				eng()->getMixer()->framesPerAudioBuffer() );
+	engine::getMixer()->clearAudioBuffer( m_firstBuffer,
+				engine::getMixer()->framesPerPeriod() );
 	qSwap( m_firstBuffer, m_secondBuffer );
 	// this is how we decrease state of buffer-usage ;-)
 	m_bufferUsage = ( m_bufferUsage != NONE ) ?
@@ -86,11 +88,11 @@ void audioPort::setExtOutputEnabled( bool _enabled )
 		m_extOutputEnabled = _enabled;
 		if( m_extOutputEnabled )
 		{
-			eng()->getMixer()->audioDev()->registerPort( this );
+			engine::getMixer()->audioDev()->registerPort( this );
 		}
 		else
 		{
-			eng()->getMixer()->audioDev()->unregisterPort( this );
+			engine::getMixer()->audioDev()->unregisterPort( this );
 		}
 	}
 }
@@ -101,7 +103,7 @@ void audioPort::setExtOutputEnabled( bool _enabled )
 void audioPort::setName( const QString & _name )
 {
 	m_name = _name;
-	eng()->getMixer()->audioDev()->renamePort( this );
+	engine::getMixer()->audioDev()->renamePort( this );
 }
 
 
