@@ -4,7 +4,7 @@
  * arp_and_chords_tab_widget.cpp - widget for use in arp/chord-tab of 
  *                                 instrument-track-window
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2008 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -41,26 +41,23 @@
 
 #endif
 
-
-/*#ifdef HAVE_STDLIB_H*/
-#include <stdlib.h>
-/*#endif*/
-
+#include <cstdlib>
 
 #include "arp_and_chords_tab_widget.h"
+#include "combobox.h"
 #include "embed.h"
+#include "engine.h"
+#include "group_box.h"
+#include "gui_templates.h"
+#include "instrument_track.h"
+#include "knob.h"
+#include "led_checkbox.h"
 #include "note_play_handle.h"
 #include "song_editor.h"
-#include "group_box.h"
 #include "pixmap_button.h"
-#include "knob.h"
-#include "tooltip.h"
-#include "gui_templates.h"
-#include "tempo_sync_knob.h"
-#include "instrument_track.h"
-#include "led_checkbox.h"
 #include "preset_preview_play_handle.h"
-#include "combobox.h"
+#include "tempo_sync_knob.h"
+#include "tooltip.h"
 
 
 
@@ -194,18 +191,18 @@ const int ARP_GROUPBOX_HEIGHT = 240 - ARP_GROUPBOX_Y;
 
 
 
-arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_track ) :
-	QWidget( _instrument_track->tabWidgetParent() ),
-	journallingObject( _instrument_track->eng() )
+arpAndChordsTabWidget::arpAndChordsTabWidget(
+					instrumentTrack * _instrument_track ) :
+	QWidget( _instrument_track->tabWidgetParent() )
 {
-	m_chordsGroupBox = new groupBox( tr( "CHORDS" ), this, eng(),
+	m_chordsGroupBox = new groupBox( tr( "CHORDS" ), this,
 							_instrument_track );
 	m_chordsGroupBox->setGeometry( CHORDS_GROUPBOX_X, CHORDS_GROUPBOX_Y,
 						CHORDS_GROUPBOX_WIDTH,
 						CHORDS_GROUPBOX_HEIGHT );
 
 	m_chordsComboBox = new comboBox( m_chordsGroupBox, tr( "Chord type" ),
-						eng(), _instrument_track );
+							_instrument_track );
 	m_chordsComboBox->setFont( pointSize<8>( m_chordsComboBox->font() ) );
 	m_chordsComboBox->setGeometry( 10, 25, 140, 22 );
 
@@ -219,8 +216,8 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 	}
 
 	m_chordRangeKnob = new knob( knobBright_26, m_chordsGroupBox,
-						tr( "Chord range" ),
-						eng(), _instrument_track );
+							tr( "Chord range" ),
+							_instrument_track );
 	m_chordRangeKnob->setLabel( tr( "RANGE" ) );
 	m_chordRangeKnob->setRange( 1.0f, 9.0f, 1.0f );
 	m_chordRangeKnob->setInitValue( 1.0f );
@@ -239,7 +236,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 
 
-	m_arpGroupBox = new groupBox( tr( "ARPEGGIO" ), this, eng(),
+	m_arpGroupBox = new groupBox( tr( "ARPEGGIO" ), this,
 							_instrument_track );
 	m_arpGroupBox->setGeometry( ARP_GROUPBOX_X, ARP_GROUPBOX_Y,
 					ARP_GROUPBOX_WIDTH,
@@ -259,7 +256,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 			"major or minor triads. But there're a lot of other "
 			"possible chords, you can select." ) );
 	m_arpComboBox = new comboBox( m_arpGroupBox, tr( "Arpeggio type" ),
-						eng(), _instrument_track );
+							_instrument_track );
 	m_arpComboBox->setFont( pointSize<8>( m_arpComboBox->font() ) );
 	m_arpComboBox->setGeometry( 10, 25, 140, 22 );
 
@@ -274,8 +271,8 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 
 	m_arpRangeKnob = new knob( knobBright_26, m_arpGroupBox,
-						tr( "Arpeggio range" ),
-						eng(), _instrument_track );
+							tr( "Arpeggio range" ),
+							_instrument_track );
 	m_arpRangeKnob->setLabel( tr( "RANGE" ) );
 	m_arpRangeKnob->setRange( 1.0f, 9.0f, 1.0f );
 	m_arpRangeKnob->setInitValue( 1.0f );
@@ -292,8 +289,8 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 			"amount of octaves." ) );
 
 	m_arpTimeKnob = new tempoSyncKnob( knobBright_26, m_arpGroupBox,
-						tr( "Arpeggio time" ),
-						eng(), _instrument_track );
+							tr( "Arpeggio time" ),
+							_instrument_track );
 	m_arpTimeKnob->setLabel( tr( "TIME" ) );
 	m_arpTimeKnob->setRange( 25.0f, 2000.0f, 1.0f );
 	m_arpTimeKnob->setInitValue( 100.0f );
@@ -310,8 +307,8 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 			"each arpeggio-tone should be played." ) );
 
 	m_arpGateKnob = new knob( knobBright_26, m_arpGroupBox,
-						tr( "Arpeggio gate" ),
-						eng(), _instrument_track );
+							tr( "Arpeggio gate" ),
+							_instrument_track );
 	m_arpGateKnob->setLabel( tr( "GATE" ) );
 	m_arpGateKnob->setRange( 1.0f, 200.0f, 1.0f );
 	m_arpGateKnob->setInitValue( 100.0f );
@@ -334,7 +331,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 
 	pixmapButton * arp_up_btn = new pixmapButton( m_arpGroupBox, NULL,
-								eng(), NULL );
+									NULL );
 	arp_up_btn->move( 10, 74 );
 	arp_up_btn->setActiveGraphic( embed::getIconPixmap( "arp_up_on" ) );
 	arp_up_btn->setInactiveGraphic( embed::getIconPixmap( "arp_up_off" ) );
@@ -345,7 +342,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 
 	pixmapButton * arp_down_btn = new pixmapButton( m_arpGroupBox, NULL,
-								eng(), NULL );
+									NULL );
 	arp_down_btn->move( 30, 74 );
 	arp_down_btn->setActiveGraphic( embed::getIconPixmap( "arp_down_on" ) );
 	arp_down_btn->setInactiveGraphic( embed::getIconPixmap(
@@ -357,7 +354,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 
 	pixmapButton * arp_up_and_down_btn = new pixmapButton( m_arpGroupBox,
-							NULL, eng(), NULL );
+								NULL, NULL );
 	arp_up_and_down_btn->move( 50, 74 );
 	arp_up_and_down_btn->setActiveGraphic( embed::getIconPixmap(
 						"arp_up_and_down_on" ) );
@@ -371,7 +368,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 
 	pixmapButton * arp_random_btn = new pixmapButton( m_arpGroupBox, NULL,
-								eng(), NULL );
+									NULL );
 	arp_random_btn->move( 70, 74 );
 	arp_random_btn->setActiveGraphic( embed::getIconPixmap(
 							"arp_random_on" ) );
@@ -384,13 +381,13 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 
 	m_arpDirectionBtnGrp = new automatableButtonGroup( this,
 						tr( "Arpeggio direction" ),
-						eng(), _instrument_track );
+						_instrument_track );
 	m_arpDirectionBtnGrp->addButton( arp_up_btn );
 	m_arpDirectionBtnGrp->addButton( arp_down_btn );
 	m_arpDirectionBtnGrp->addButton( arp_up_and_down_btn );
 	m_arpDirectionBtnGrp->addButton( arp_random_btn );
 
-	m_arpDirectionBtnGrp->setInitValue( UP - 1 );
+	m_arpDirectionBtnGrp->setInitValue( UP );
 
 
 	QLabel * mode_lbl = new QLabel( tr( "Mode:" ), m_arpGroupBox );
@@ -398,7 +395,7 @@ arpAndChordsTabWidget::arpAndChordsTabWidget( instrumentTrack * _instrument_trac
 	mode_lbl->setFont( pointSize<7>( mode_lbl->font() ) );
 
 	m_arpModeComboBox = new comboBox( m_arpGroupBox, tr( "Arpeggio mode" ),
-						eng(), _instrument_track );
+							_instrument_track );
 	m_arpModeComboBox->setFont( pointSize<8>( m_arpModeComboBox->font() ) );
 	m_arpModeComboBox->setGeometry( 10, 118, 128, 22 );
 
@@ -461,24 +458,20 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 					break;
 				}
 				// create copy of base-note
-				note note_copy( NULL, 0, 0,
+				note note_copy( _n->length(), 0,
 						(tones)( sub_note_key %
 							NOTES_PER_OCTAVE ),
 						(octaves)( sub_note_key /
 							NOTES_PER_OCTAVE ),
 							_n->getVolume(),
-							_n->getPanning() );
-				note_copy.setDetuning( _n->detuning() );
-				// duplicate note-play-handle, only note is
+							_n->getPanning(),
+							_n->detuning() );
+				// create sub-note-play-handle, only note is
 				// different
-				notePlayHandle * note_play_handle =
-					new notePlayHandle(
-						_n->getInstrumentTrack(),
-						_n->framesAhead(),
-						_n->frames(), note_copy );
-				// add sub-note to base-note, now all stuff is
-				// done by notePlayHandle::play_note()
-				_n->addSubNote( note_play_handle );
+				new notePlayHandle( _n->getInstrumentTrack(),
+							_n->offset(),
+							_n->frames(), note_copy,
+							_n );
 			}
 		}
 	}
@@ -487,7 +480,6 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 	// now follows code for arpeggio
 
 	if( _n->baseNote() == FALSE ||
-		( m_arpDirectionBtnGrp->value() + 1) == OFF ||
 			!m_arpGroupBox->isActive() ||
 			( _n->released() && _n->releaseFramesDone() >=
 					_n->actualReleaseFramesToDo() ) )
@@ -519,7 +511,7 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 
 	// number of frames that every note should be played
 	const f_cnt_t arp_frames = (f_cnt_t)( m_arpTimeKnob->value() / 1000.0f *
-					eng()->getMixer()->sampleRate() );
+					engine::getMixer()->sampleRate() );
 	const f_cnt_t gated_frames = (f_cnt_t)( m_arpGateKnob->value() *
 							arp_frames / 100.0f );
 
@@ -532,13 +524,13 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 	// used for loop
 	f_cnt_t frames_processed = 0;
 
-	while( frames_processed < eng()->getMixer()->framesPerAudioBuffer() )
+	while( frames_processed < engine::getMixer()->framesPerPeriod() )
 	{
 		const f_cnt_t remaining_frames_for_cur_arp = arp_frames -
 						( cur_frame % arp_frames );
 		// does current arp-note fill whole audio-buffer?
 		if( remaining_frames_for_cur_arp >
-				eng()->getMixer()->framesPerAudioBuffer() )
+				engine::getMixer()->framesPerPeriod() )
 		{
 			// then we don't have to do something!
 			break;
@@ -561,8 +553,7 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 			continue;
 		}
 
-		arpDirections dir = static_cast<arpDirections>(
-					m_arpDirectionBtnGrp->value() + 1 );
+		const int dir = m_arpDirectionBtnGrp->value();
 		// process according to arpeggio-direction...
 		if( dir == UP )
 		{
@@ -604,7 +595,8 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 
 		// range-checking
 		if( sub_note_key >= NOTES_PER_OCTAVE * OCTAVES ||
-			sub_note_key < 0 || eng()->getMixer()->criticalXRuns() )
+			sub_note_key < 0 ||
+					engine::getMixer()->criticalXRuns() )
 		{
 			continue;
 		}
@@ -616,32 +608,25 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 		}
 
 		// create new arp-note
-		note new_note( NULL, midiTime( 0 ), midiTime( 0 ),
+		note new_note( midiTime( 0 ), midiTime( 0 ),
 				static_cast<tones>( sub_note_key %
 							NOTES_PER_OCTAVE ),
 				static_cast<octaves>( sub_note_key /
 							NOTES_PER_OCTAVE ),
 				static_cast<volume>( _n->getVolume() *
 								vol_level ),
-				_n->getPanning() );
-		new_note.setDetuning( _n->detuning() );
+				_n->getPanning(), _n->detuning() );
 
-		// duplicate note-play-handle, only ptr to note is different
+		// create sub-note-play-handle, only ptr to note is different
 		// and is_arp_note=TRUE
-		notePlayHandle * note_play_handle = new notePlayHandle(
-						_n->getInstrumentTrack(),
-					( ( m_arpModeComboBox->value() !=
-					    				FREE ) ?
-						cnphv.first()->framesAhead() :
-						_n->framesAhead() ) +
+		new notePlayHandle( _n->getInstrumentTrack(),
+				( ( m_arpModeComboBox->value() != FREE ) ?
+						cnphv.first()->offset() :
+						_n->offset() ) +
 							frames_processed,
 						gated_frames,
 						new_note,
-						TRUE );
-
-		// add sub-note to base-note - now all stuff is done by
-		// notePlayHandle::playNote()
-		_n->addSubNote( note_play_handle );
+						_n, TRUE );
 
 		// update counters
 		frames_processed += arp_frames;
@@ -662,18 +647,16 @@ void arpAndChordsTabWidget::processNote( notePlayHandle * _n )
 void arpAndChordsTabWidget::saveSettings( QDomDocument & _doc,
 							QDomElement & _this )
 {
-	_this.setAttribute( "chorddisabled", !m_chordsGroupBox->isActive() );
+	m_chordsGroupBox->saveSettings( _doc, _this, "chord-enabled" );
 	m_chordsComboBox->saveSettings( _doc, _this, "chord" );
 	m_chordRangeKnob->saveSettings( _doc, _this, "chordrange" );
 
-	_this.setAttribute( "arpdisabled", !m_arpGroupBox->isActive() );
+	m_arpGroupBox->saveSettings( _doc, _this, "arp-enabled" );
 	m_arpComboBox->saveSettings( _doc, _this, "arp" );
 	m_arpRangeKnob->saveSettings( _doc, _this, "arprange" );
 	m_arpTimeKnob->saveSettings( _doc, _this, "arptime" );
 	m_arpGateKnob->saveSettings( _doc, _this, "arpgate" );
 	m_arpDirectionBtnGrp->saveSettings( _doc, _this, "arpdir" );
-	_this.setAttribute( "arpsyncmode",
-					( int ) m_arpTimeKnob->getSyncMode() );
 
 	m_arpModeComboBox->saveSettings( _doc, _this, "arpmode" );
 }
@@ -683,31 +666,26 @@ void arpAndChordsTabWidget::saveSettings( QDomDocument & _doc,
 
 void arpAndChordsTabWidget::loadSettings( const QDomElement & _this )
 {
-	m_chordsGroupBox->setState( !_this.attribute
-						( "chorddisabled" ).toInt() );
+	m_chordsGroupBox->loadSettings( _this, "chord-enabled" );
 	m_chordsComboBox->loadSettings( _this, "chord" );
 	m_chordRangeKnob->loadSettings( _this, "chordrange" );
+
+	m_arpGroupBox->loadSettings( _this, "arp-enabled" );
 	m_arpComboBox->loadSettings( _this, "arp" );
 	m_arpRangeKnob->loadSettings( _this, "arprange" );
 	m_arpTimeKnob->loadSettings( _this, "arptime" );
 	m_arpGateKnob->loadSettings( _this, "arpgate" );
-	if( _this.hasAttribute( "arpdir" ) )
+	m_arpDirectionBtnGrp->loadSettings( _this, "arpdir" );
+
+	// Keep compatibility with version 0.2.1 file format
+	if( _this.hasAttribute( "arpsyncmode" ) )
 	{
-		m_arpDirectionBtnGrp->setInitValue(
-				_this.attribute( "arpdir" ).toInt() - 1 );
+	 	m_arpTimeKnob->setSyncMode( 
+ 		( tempoSyncKnob::tempoSyncMode ) _this.attribute(
+ 						 "arpsyncmode" ).toInt() );
 	}
-	else
-	{
-		m_arpDirectionBtnGrp->loadSettings( _this, "arpdir" );
-	}
-	m_arpTimeKnob->setSyncMode( 
-		( tempoSyncKnob::tempoSyncMode ) _this.attribute(
-						 "arpsyncmode" ).toInt() );
 
 	m_arpModeComboBox->loadSettings( _this, "arpmode" );
-
-	m_arpGroupBox->setState( _this.attribute( "arpdir" ).toInt() != OFF &&
-				!_this.attribute( "arpdisabled" ).toInt() );
 }
 
 
