@@ -4,7 +4,7 @@
  * file_browser.cpp - implementation of the project-, preset- and
  *                    sample-file-browser
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -48,34 +48,34 @@
 
 
 #include "file_browser.h"
-#include "song_editor.h"
 #include "bb_editor.h"
+#include "config_mgr.h"
+#include "debug.h"
 #include "embed.h"
+#include "engine.h"
+#include "gui_templates.h"
+#include "instrument.h"
 #include "instrument_track.h"
+#include "main_window.h"
 #include "mmp.h"
 #include "preset_preview_play_handle.h"
 #include "sample_play_handle.h"
-#include "debug.h"
-#include "gui_templates.h"
-#include "instrument.h"
-#include "text_float.h"
+#include "song_editor.h"
 #include "string_pair_drag.h"
-#include "main_window.h"
-#include "config_mgr.h"
+#include "text_float.h"
 
 
 
 fileBrowser::fileBrowser( const QString & _directories, const QString & _filter,
 			const QString & _title, const QPixmap & _pm,
-					QWidget * _parent, engine * _engine  ) :
+							QWidget * _parent ) :
 	sideBarWidget( _title, _pm, _parent ),
-	engineObject( _engine ),
 	m_contextMenuItem( NULL ),
 	m_directories( _directories ),
 	m_filter( _filter )
 {
 	setWindowTitle( tr( "Browser" ) );
-	m_l = new listView( contentParent(), eng() );
+	m_l = new listView( contentParent() );
 	addContentWidget( m_l );
 
 #ifdef QT4
@@ -123,7 +123,11 @@ void fileBrowser::reloadTree( void )
 		addItems( *it );
 	}
 
+#ifndef QT3
 	Q3ListViewItem * item = m_l->firstChild();
+#else
+	QListViewItem * item = m_l->firstChild();
+#endif
 	bool resort = FALSE;
 
 	// sort merged directories
@@ -136,7 +140,11 @@ void fileBrowser::reloadTree( void )
 		}
 		else if( resort == TRUE )
 		{
+#ifndef QT3
 			Q3ListViewItem * i2 = m_l->firstChild();
+#else
+			QListViewItem * i2 = m_l->firstChild();
+#endif
 			d->moveItem( i2 );
 			i2->moveItem( d );
 			directory * d2 = NULL;
@@ -160,7 +168,7 @@ void fileBrowser::reloadTree( void )
 void fileBrowser::addItems( const QString & _path )
 {
 	QDir cdir( _path );
-	QStringList files = cdir.entryList( QDir::NoFilter, QDir::Name );
+	QStringList files = cdir.entryList( QDir::Files, QDir::Name );
 
 	// TODO: after dropping qt3-support we can use QStringList's iterator
 	// which makes it possible to travel through the list in reverse
@@ -169,9 +177,7 @@ void fileBrowser::addItems( const QString & _path )
 	for( csize i = 0; i < files.size(); ++i )
 	{
 		QString cur_file = files[files.size() - i - 1];
-		if( cur_file[0] != '.' &&
-			QFileInfo( _path + QDir::separator() +
-						cur_file ).isDir() == FALSE
+		if( cur_file[0] != '.'
 #ifdef QT4
 // TBD
 #else
@@ -185,14 +191,19 @@ void fileBrowser::addItems( const QString & _path )
 		}
 	}
 
+	files = cdir.entryList( QDir::Dirs, QDir::Name );
 	for( csize i = 0; i < files.size(); ++i )
 	{
 		QString cur_file = files[files.size() - i - 1];
 		if( cur_file[0] != '.' &&
-			QFileInfo( _path + QDir::separator() +
-							cur_file ).isDir() )
+			isDirWithContent( _path + QDir::separator() + cur_file,
+								m_filter ) )
 		{
+#ifdef QT4
+			Q3ListViewItem * item = m_l->findItem( cur_file, 0 );
+#else
 			QListViewItem * item = m_l->findItem( cur_file, 0 );
+#endif
 			if( item == NULL )
 			{
 				(void) new directory( m_l, cur_file, _path,
@@ -210,6 +221,44 @@ void fileBrowser::addItems( const QString & _path )
 
 
 
+bool fileBrowser::isDirWithContent( const QString & _path,
+						const QString & _filter )
+{
+	QDir cdir( _path );
+	QStringList files = cdir.entryList( QDir::Files, QDir::Unsorted );
+	for( QStringList::iterator it = files.begin(); it != files.end(); ++it )
+	{
+		QString cur_file = *it;
+		if( cur_file[0] != '.'
+#ifdef QT4
+// TBD
+#else
+			&& QDir::match( _filter, cur_file.lower() )
+#endif
+	)
+		{
+			return( TRUE );
+		}
+	}
+
+	files = cdir.entryList( QDir::Dirs, QDir::Unsorted );
+	for( QStringList::iterator it = files.begin(); it != files.end(); ++it )
+	{
+		QString cur_file = *it;
+		if( cur_file[0] != '.' &&
+			isDirWithContent( _path + QDir::separator() + cur_file,
+								_filter ) )
+		{
+			return( TRUE );
+		}
+	}
+
+	return( FALSE );
+}
+
+
+
+
 void fileBrowser::keyPressEvent( QKeyEvent * _ke )
 {
 	if( _ke->key() == Qt::Key_F5 )
@@ -225,7 +274,6 @@ void fileBrowser::keyPressEvent( QKeyEvent * _ke )
 
 
 
-
 #ifdef QT4
 void fileBrowser::contextMenuRequest( Q3ListViewItem * i, const QPoint &, int )
 #else
@@ -259,67 +307,80 @@ void fileBrowser::contextMenuRequest( QListViewItem * i, const QPoint &, int )
 
 
 
+#ifdef QT4
+void fileBrowser::contextMenuRequest( QListViewItem * i, const QPoint &, int )
+#else
+void fileBrowser::contextMenuRequest( Q3ListViewItem * i, const QPoint &, int )
+#endif
+{
+}
+
+
+
+
 void fileBrowser::sendToActiveInstrumentTrack( void )
 {
-	if( eng()->getMainWindow()->workspace() != NULL )
+	if( engine::getMainWindow()->workspace() == NULL )
 	{
-		// get all windows opened in the workspace
-		QWidgetList pl =
-			eng()->getMainWindow()->workspace()->windowList(
+		return;
+	}
+
+	// get all windows opened in the workspace
+	QWidgetList pl = engine::getMainWindow()->workspace()->windowList(
 #if QT_VERSION >= 0x030200
 						QWorkspace::StackingOrder
 #endif
 									);
 #ifdef QT4
-		QListIterator<QWidget *> w( pl );
-		w.toBack();
-		// now we travel through the window-list until we find an
-		// instrument-track
-		while( w.hasPrevious() )
-		{
-			instrumentTrack * ct = dynamic_cast<instrumentTrack *>(
+	QListIterator<QWidget *> w( pl );
+	w.toBack();
+	// now we travel through the window-list until we find an
+	// instrument-track
+	while( w.hasPrevious() )
+	{
+		instrumentTrack * ct = dynamic_cast<instrumentTrack *>(
 								w.previous() );
 #else
-		QWidget * w = pl.last();
-		// now we travel through the window-list until we find an
-		// instrument-track
-		while( w != NULL )
-		{
-			instrumentTrack * ct =
-					dynamic_cast<instrumentTrack *>( w );
+	QWidget * w = pl.last();
+	// now we travel through the window-list until we find an
+	// instrument-track
+	while( w != NULL )
+	{
+		instrumentTrack * ct = dynamic_cast<instrumentTrack *>( w );
 #endif
-			if( ct != NULL && ct->isHidden() == FALSE )
+		if( ct != NULL && ct->isHidden() == FALSE )
+		{
+			// ok, it's an instrument-track, so we can apply the
+			// sample or the preset
+			engine::getMixer()->lock();
+			if( m_contextMenuItem->type() == fileItem::SAMPLE_FILE )
 			{
-				// ok, it's an instrument-track, so we can apply
-				// the sample or the preset
-				if( m_contextMenuItem->type() ==
-							fileItem::SAMPLE_FILE )
+				instrument * afp = ct->loadInstrument(
+						engine::sampleExtensions()
+							[m_contextMenuItem
+							->extension()] );
+				if( afp != NULL )
 				{
-					instrument * afp = ct->loadInstrument(
-							"audiofileprocessor" );
-					if( afp != NULL )
-					{
-						afp->setParameter( "samplefile",
+					afp->setParameter( "samplefile",
 						m_contextMenuItem->fullName() );
-					}
 				}
-				else if( m_contextMenuItem->type() ==
+			}
+			else if( m_contextMenuItem->type() ==
 							fileItem::PRESET_FILE )
-				{
-					multimediaProject mmp(
+			{
+				multimediaProject mmp(
 						m_contextMenuItem->fullName() );
-					ct->loadTrackSpecificSettings(
-								mmp.content().
+				ct->loadTrackSpecificSettings( mmp.content().
 								firstChild().
 								toElement() );
-				}
-				ct->toggledInstrumentTrackButton( TRUE );
-				break;
 			}
-#ifndef QT4
-			w = pl.prev();
-#endif
+			ct->toggledInstrumentTrackButton( TRUE );
+			engine::getMixer()->unlock();
+			break;
 		}
+#ifndef QT4
+		w = pl.prev();
+#endif
 	}
 }
 
@@ -328,14 +389,18 @@ void fileBrowser::sendToActiveInstrumentTrack( void )
 
 void fileBrowser::openInNewInstrumentTrack( trackContainer * _tc )
 {
+	engine::getMixer()->lock();
 	if( m_contextMenuItem->type() == fileItem::SAMPLE_FILE )
 	{
 		instrumentTrack * ct = dynamic_cast<instrumentTrack *>(
-			track::create( track::CHANNEL_TRACK, _tc ) );
+			track::create( track::INSTRUMENT_TRACK, _tc ) );
 #ifdef LMMS_DEBUG
 		assert( ct != NULL );
 #endif
-		instrument * afp = ct->loadInstrument( "audiofileprocessor" );
+		instrument * afp = ct->loadInstrument(
+					engine::sampleExtensions()
+						[m_contextMenuItem
+							->extension()] );
 		if( afp != NULL )
 		{
 			afp->setParameter( "samplefile",
@@ -346,7 +411,7 @@ void fileBrowser::openInNewInstrumentTrack( trackContainer * _tc )
 	else if( m_contextMenuItem->type() == fileItem::PRESET_FILE )
 	{
 		multimediaProject mmp( m_contextMenuItem->fullName() );
-		track * t = track::create( track::CHANNEL_TRACK, _tc );
+		track * t = track::create( track::INSTRUMENT_TRACK, _tc );
 		instrumentTrack * ct = dynamic_cast<instrumentTrack *>( t );
 		if( ct != NULL )
 		{
@@ -356,6 +421,7 @@ void fileBrowser::openInNewInstrumentTrack( trackContainer * _tc )
 			ct->toggledInstrumentTrackButton( TRUE );
 		}
 	}
+	engine::getMixer()->unlock();
 }
 
 
@@ -363,7 +429,7 @@ void fileBrowser::openInNewInstrumentTrack( trackContainer * _tc )
 
 void fileBrowser::openInNewInstrumentTrackSE( void )
 {
-	openInNewInstrumentTrack( eng()->getSongEditor() );
+	openInNewInstrumentTrack( engine::getSongEditor() );
 }
 
 
@@ -371,7 +437,7 @@ void fileBrowser::openInNewInstrumentTrackSE( void )
 
 void fileBrowser::openInNewInstrumentTrackBBE( void )
 {
-	openInNewInstrumentTrack( eng()->getBBEditor() );
+	openInNewInstrumentTrack( engine::getBBEditor() );
 }
 
 
@@ -381,12 +447,12 @@ void fileBrowser::openInNewInstrumentTrackBBE( void )
 
 
 
-listView::listView( QWidget * _parent, engine * _engine ) :
+listView::listView( QWidget * _parent ) :
 	Q3ListView( _parent ),
-	engineObject( _engine ),
 	m_mousePressed( FALSE ),
 	m_pressPos(),
-	m_previewPlayHandle( NULL )
+	m_previewPlayHandle( NULL ),
+	m_pphMutex()
 {
 	addColumn( tr( "Files" ) );
 	setTreeStepSize( 12 );
@@ -411,50 +477,53 @@ void listView::contentsMouseDoubleClickEvent( QMouseEvent * _me )
 	Q3ListView::contentsMouseDoubleClickEvent( _me );
 	fileItem * f = dynamic_cast<fileItem *>( itemAt(
 					contentsToViewport( _me->pos() ) ) );
-	if( f != NULL )
+	if( f == NULL )
 	{
-		if( f->type() == fileItem::SAMPLE_FILE )
-		{
-			// samples are per default opened in bb-editor because
-			// they're likely drum-samples etc.
-			instrumentTrack * it = dynamic_cast<instrumentTrack *>(
-				track::create( track::CHANNEL_TRACK,
-						eng()->getBBEditor() ) );
+		return;
+	}
+
+	if( f->type() == fileItem::SAMPLE_FILE )
+	{
+		// samples are per default opened in bb-editor because they're
+		// likely drum-samples etc.
+		engine::getMixer()->lock();
+		instrumentTrack * it = dynamic_cast<instrumentTrack *>(
+				track::create( track::INSTRUMENT_TRACK,
+						engine::getBBEditor() ) );
 #ifdef LMMS_DEBUG
-			assert( it != NULL );
+		assert( it != NULL );
 #endif
-			instrument * afp = it->loadInstrument(
-							"audiofileprocessor" );
-			if( afp != NULL )
-			{
-				afp->setParameter( "samplefile",
-								f->fullName() );
-			}
-			it->toggledInstrumentTrackButton( TRUE );
-		}
-		else if( f->type() == fileItem::PRESET_FILE )
+		instrument * afp = it->loadInstrument(
+				engine::sampleExtensions()[f->extension()] );
+		if( afp != NULL )
 		{
-			// presets are per default opened in bb-editor
-			multimediaProject mmp( f->fullName() );
-			track * t = track::create( track::CHANNEL_TRACK,
-						eng()->getBBEditor() );
-			instrumentTrack * it = dynamic_cast<instrumentTrack *>(
-									t );
-			if( it != NULL )
-			{
-				it->loadTrackSpecificSettings( mmp.content().
+			afp->setParameter( "samplefile", f->fullName() );
+		}
+		it->toggledInstrumentTrackButton( TRUE );
+		engine::getMixer()->unlock();
+	}
+	else if( f->type() == fileItem::PRESET_FILE )
+	{
+		// presets are per default opened in bb-editor
+		multimediaProject mmp( f->fullName() );
+		engine::getMixer()->lock();
+		instrumentTrack * it = dynamic_cast<instrumentTrack *>(
+				track::create( track::INSTRUMENT_TRACK,
+						engine::getBBEditor() ) );
+		if( it != NULL )
+		{
+			it->loadTrackSpecificSettings( mmp.content().
 								firstChild().
 								toElement() );
-				it->toggledInstrumentTrackButton( TRUE );
-			}
+			it->toggledInstrumentTrackButton( TRUE );
 		}
-		else if( f->type() == fileItem::PROJECT_FILE )
+		engine::getMixer()->unlock();
+	}
+	else if( f->type() == fileItem::PROJECT_FILE )
+	{
+		if( engine::getSongEditor()->mayChangeProject() )
 		{
-			if( eng()->getSongEditor()->mayChangeProject() == TRUE )
-			{
-				eng()->getSongEditor()->loadProject(
-								f->fullName() );
-			}
+			engine::getSongEditor()->loadProject( f->fullName() );
 		}
 	}
 }
@@ -471,7 +540,11 @@ void listView::contentsMousePressEvent( QMouseEvent * _me )
 	}
 
 	QPoint p( contentsToViewport( _me->pos() ) );
+#ifndef QT3
 	Q3ListViewItem * i = itemAt( p );
+#else
+	QListViewItem * i = itemAt( p );
+#endif
         if ( i )
 	{
 		if ( p.x() > header()->cellPos( header()->mapToActual( 0 ) ) +
@@ -488,9 +561,13 @@ void listView::contentsMousePressEvent( QMouseEvent * _me )
 	fileItem * f = dynamic_cast<fileItem *>( i );
 	if( f != NULL )
 	{
+		if( !m_pphMutex.tryLock() )
+		{
+			return;
+		}
 		if( m_previewPlayHandle != NULL )
 		{
-			eng()->getMixer()->removePlayHandle(
+			engine::getMixer()->removePlayHandle(
 							m_previewPlayHandle );
 			m_previewPlayHandle = NULL;
 		}
@@ -508,7 +585,7 @@ void listView::contentsMousePressEvent( QMouseEvent * _me )
 			qApp->processEvents();
 #endif
 			samplePlayHandle * s = new samplePlayHandle(
-							f->fullName(), eng() );
+								f->fullName() );
 			s->setDoneMayReturnTrue( FALSE );
 			m_previewPlayHandle = s;
 			delete tf;
@@ -516,12 +593,14 @@ void listView::contentsMousePressEvent( QMouseEvent * _me )
 		else if( f->type() == fileItem::PRESET_FILE )
 		{
 			m_previewPlayHandle = new presetPreviewPlayHandle(
-							f->fullName(), eng() );
+								f->fullName() );
 		}
 		if( m_previewPlayHandle != NULL )
 		{
-			eng()->getMixer()->addPlayHandle( m_previewPlayHandle );
+			engine::getMixer()->addPlayHandle(
+							m_previewPlayHandle );
 		}
+		m_pphMutex.unlock();
 	}
 }
 
@@ -546,7 +625,7 @@ void listView::contentsMouseMoveEvent( QMouseEvent * _me )
 								f->fullName(),
 							embed::getIconPixmap(
 								"preset_file" ),
-								this, eng() );
+									this );
 					break;
 
 				case fileItem::SAMPLE_FILE:
@@ -554,7 +633,7 @@ void listView::contentsMouseMoveEvent( QMouseEvent * _me )
 								f->fullName(),
 							embed::getIconPixmap(
 								"sound_file" ),
-								this, eng() );
+									this );
 					break;
 
 				case fileItem::MIDI_FILE:
@@ -562,7 +641,7 @@ void listView::contentsMouseMoveEvent( QMouseEvent * _me )
 								f->fullName(),
 							embed::getIconPixmap(
 								"midi_file" ),
-								this, eng() );
+									this );
 					break;
 
 				default:
@@ -577,6 +656,11 @@ void listView::contentsMouseMoveEvent( QMouseEvent * _me )
 
 void listView::contentsMouseReleaseEvent( QMouseEvent * _me )
 {
+	if( !m_pphMutex.tryLock() )
+	{
+		return;
+	}
+
 	m_mousePressed = FALSE;
 	if( m_previewPlayHandle != NULL )
 	{
@@ -588,16 +672,18 @@ void listView::contentsMouseReleaseEvent( QMouseEvent * _me )
 		{
 			if( s->totalFrames() - s->framesDone() <=
 				static_cast<f_cnt_t>(
-					eng()->getMixer()->sampleRate() * 3 ) )
+					engine::getMixer()->sampleRate() * 3 ) )
 			{
 				s->setDoneMayReturnTrue( TRUE );
 				m_previewPlayHandle = NULL;
+				m_pphMutex.unlock();
 				return;
 			}
 		}
-		eng()->getMixer()->removePlayHandle( m_previewPlayHandle );
+		engine::getMixer()->removePlayHandle( m_previewPlayHandle );
 		m_previewPlayHandle = NULL;
 	}
+	m_pphMutex.unlock();
 }
 
 
@@ -613,7 +699,11 @@ QPixmap * directory::s_folderLockedPixmap = NULL;
 
 directory::directory( directory * _parent, const QString & _name,
 			const QString & _path, const QString & _filter ) :
+#ifndef QT3
 	Q3ListViewItem( _parent, _name ),
+#else
+	QListViewItem( _parent, _name ),
+#endif
 	m_p( _parent ),
 	m_pix( NULL ),
 	m_directories( _path ),
@@ -627,7 +717,11 @@ directory::directory( directory * _parent, const QString & _name,
 
 directory::directory( Q3ListView * _parent, const QString & _name,
 			const QString & _path, const QString & _filter ) :
+#ifndef QT3
 	Q3ListViewItem( _parent, _name ),
+#else
+	QListViewItem( _parent, _name ),
+#endif
 	m_p( NULL ),
 	m_pix( NULL ),
 	m_directories( _path ),
@@ -705,13 +799,21 @@ void directory::setOpen( bool _o )
 				( *it ).contains(
 					configManager::inst()->dataDir() ) )
 			{
+#ifndef QT3
+				( new Q3ListViewItem( this,
+#else
 				( new QListViewItem( this,
+#endif
 		listView::tr( "--- Factory files ---" ) ) )->setPixmap( 0,
 				embed::getIconPixmap( "factory_files" ) );
 			}
 		}
 	}
+#ifndef QT3
 	Q3ListViewItem::setOpen( _o );
+#else
+	QListViewItem::setOpen( _o );
+#endif
 }
 
 
@@ -720,7 +822,11 @@ void directory::setOpen( bool _o )
 void directory::setup( void )
 {
 	setExpandable( TRUE );
+#ifndef QT3
 	Q3ListViewItem::setup();
+#else
+	QListViewItem::setup();
+#endif
 }
 
 
@@ -740,41 +846,34 @@ bool directory::addItems( const QString & _path )
 
 	bool added_something = FALSE;
 
-	QStringList files = thisDir.entryList( QDir::NoFilter, QDir::Name );
+	QStringList files = thisDir.entryList( QDir::Files, QDir::Name );
 	for( csize i = 0; i < files.size(); ++i )
 	{
 		QString cur_file = files[files.size() - i - 1];
+		if( cur_file[0] != '.'
 #ifdef QT4
-		if( cur_file[0] != '.' && !QFileInfo(
-				thisDir.absolutePath() + QDir::separator() +
-						cur_file ).isDir() &&
-			thisDir.match( m_filter, cur_file.toLower() )
-			/*QDir::match( FILE_FILTER, cur_file )*/ )
+				&& thisDir.match( m_filter, cur_file.toLower() )
 #else
-		if( cur_file[0] != '.' && !QFileInfo(
-					thisDir.absPath() + QDir::separator() +
-						cur_file ).isDir() &&
-			thisDir.match( m_filter, cur_file.lower() )
-			/*QDir::match( FILE_FILTER, cur_file )*/ )
+				&& thisDir.match( m_filter, cur_file.lower() )
 #endif
+			/*QDir::match( FILE_FILTER, cur_file )*/ )
 		{
 			(void) new fileItem( this, cur_file, _path );
 			added_something = TRUE;
 		}
 	}
 
+	files = thisDir.entryList( QDir::Dirs, QDir::Name );
 	for( csize i = 0; i < files.size(); ++i )
 	{
 		QString cur_file = files[files.size() - i - 1];
+		if( cur_file[0] != '.' && fileBrowser::isDirWithContent(
 #ifdef QT4
-		if( cur_file[0] != '.' && QFileInfo(
 				thisDir.absolutePath() + QDir::separator() +
-						cur_file ).isDir() )
 #else
-		if( cur_file[0] != '.' && QFileInfo(
 					thisDir.absPath() + QDir::separator() +
-						cur_file ).isDir() )
 #endif
+							cur_file, m_filter ) )
 		{
 			new directory( this, cur_file, _path, m_filter );
 			added_something = TRUE;
@@ -823,7 +922,12 @@ QPixmap * fileItem::s_unknownFilePixmap = NULL;
 
 fileItem::fileItem( Q3ListView * _parent, const QString & _name,
 						const QString & _path ) :
+#ifndef QT3
 	Q3ListViewItem( _parent, _name ),
+#else
+	QListViewItem( _parent, _name ),
+#endif
+	m_pix( NULL ),
 	m_path( _path )
 {
 	determineFileType();
@@ -834,9 +938,16 @@ fileItem::fileItem( Q3ListView * _parent, const QString & _name,
 
 
 
+#ifndef QT3
 fileItem::fileItem( Q3ListViewItem * _parent, const QString & _name,
 						const QString & _path ) :
 	Q3ListViewItem( _parent, _name ),
+#else
+fileItem::fileItem( QListViewItem * _parent, const QString & _name,
+						const QString & _path ) :
+	QListViewItem( _parent, _name ),
+#endif
+	m_pix( NULL ),
 	m_path( _path )
 {
 	determineFileType();
@@ -904,12 +1015,8 @@ void fileItem::initPixmapStuff( void )
 
 void fileItem::determineFileType( void )
 {
-#ifdef QT4
-	QString ext = QFileInfo( fullName() ).suffix().toLower();
-#else
-	QString ext = QFileInfo( fullName() ).extension( FALSE ).toLower();
-#endif
-	if( ext == "mmp" || ext == "mpt" )
+	QString ext = extension();
+	if( ext == "mmp" || ext == "mpt" || ext == "mmpz" )
 	{
 		m_type = PROJECT_FILE;
 	}
@@ -934,9 +1041,7 @@ void fileItem::determineFileType( void )
 	{
 		m_type = PRESET_FILE;
 	}
-	else if( ext == "wav" || ext == "ogg" || ext == "mp3" ||
-			ext == "aiff" || ext == "aif" || ext == "voc" ||
-			ext == "au" || ext == "raw" || ext == "flac" )
+	else if( engine::sampleExtensions().contains( ext ) )
 	{
 		m_type = SAMPLE_FILE;
 	}
@@ -957,6 +1062,25 @@ void fileItem::determineFileType( void )
 
 
 
+QString fileItem::extension( void )
+{
+	return( extension( fullName() ) );
+}
+
+
+
+
+QString fileItem::extension( const QString & _file )
+{
+#ifdef QT4
+	return( QFileInfo( _file ).suffix().toLower() );
+#else
+	return( QFileInfo( _file ).extension( FALSE ).toLower() );
+#endif
+}
+
+
+
 
 #include "file_browser.moc"
 
