@@ -3,7 +3,7 @@
 /*
  * main.cpp - just main.cpp which is starting up app...
  *
- * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -52,6 +52,7 @@
 
 #include "main_window.h"
 #include "embed.h"
+#include "engine.h"
 #include "config_mgr.h"
 #include "export_project_dialog.h"
 #include "song_editor.h"
@@ -101,7 +102,7 @@ int main( int argc, char * * argv )
 					QString( app.argv()[i] ) == "-v" )
 		{
 			printf( "\nLinux MultiMedia Studio %s\n\n"
-	"Copyright (c) 2004-2006 Tobias Doerffel and others.\n\n"
+	"Copyright (c) 2004-2007 Tobias Doerffel and others.\n\n"
 	"This program is free software; you can redistribute it and/or\n"
 	"modify it under the terms of the GNU General Public\n"
 	"License as published by the Free Software Foundation; either\n"
@@ -115,7 +116,7 @@ int main( int argc, char * * argv )
 					QString( app.argv()[i] ) == "-h" ) )
 		{
 			printf( "\nLinux MultiMedia Studio %s\n"
-	"Copyright (c) 2004-2006 Tobias Doerffel and others.\n\n"
+	"Copyright (c) 2004-2007 Tobias Doerffel and others.\n\n"
 	"usage: lmms [ -r <file_to_render> [ -o <format> ] [ -h ] "
 							"[ <file_to_load> ]\n"
 	"-r, --render			render given file.\n"
@@ -230,32 +231,32 @@ int main( int argc, char * * argv )
 							Qt::white );
 #endif
 
-	engine * main_engine = new engine();
+	engine::init();
 
 	// we try to load given file
 	if( file_to_load != "" )
 	{
-		main_engine->getSongEditor()->loadProject( file_to_load );
+		engine::getSongEditor()->loadProject( file_to_load );
 	}
 	else
 	{
-		main_engine->getSongEditor()->createNewProject();
+		engine::getSongEditor()->createNewProject();
 	}
 #ifndef QT4
-	app.setMainWidget( main_engine->getMainWindow() );
+	app.setMainWidget( engine::getMainWindow() );
 #endif
 	// MDI-mode?
-	if( main_engine->getMainWindow()->workspace() != NULL )
+	if( engine::getMainWindow()->workspace() != NULL )
 	{
 		// then maximize
-		main_engine->getMainWindow()->showMaximized();
+		engine::getMainWindow()->showMaximized();
 	}
 	else
 	{
 		// otherwise arrange at top-left edge of screen
-		main_engine->getMainWindow()->show();
-		main_engine->getMainWindow()->move( 0, 0 );
-		main_engine->getMainWindow()->resize( 200, 500 );
+		engine::getMainWindow()->show();
+		engine::getMainWindow()->move( 0, 0 );
+		engine::getMainWindow()->resize( 200, 500 );
 	}
 
 
@@ -267,8 +268,7 @@ int main( int argc, char * * argv )
 	{
 		exportProjectDialog * e = new exportProjectDialog(
 						file_to_render,
-						main_engine->getMainWindow(),
-						main_engine );
+						engine::getMainWindow() );
 		e->show();
 		e->exportBtnClicked();
 	}
