@@ -987,6 +987,12 @@ void pianoRoll::updatePaintPixmap( QPixmap & _p )
 						( *it )->getVolume() / 2,
 					x + WHITE_KEY_WIDTH + 1,
 					height() - PR_BOTTOM_MARGIN );
+			p.drawLine( x + WHITE_KEY_WIDTH-1,
+					height() - PR_BOTTOM_MARGIN -
+						( *it )->getVolume() / 2+2,
+					x + WHITE_KEY_WIDTH + 4,
+					height() - PR_BOTTOM_MARGIN -
+						( *it )->getVolume() / 2+2 );
 
 			if( ( *it )->hasDetuningInfo() )
 			{
@@ -1361,7 +1367,9 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 						pattern::MELODY_PATTERN );
 
 					// then set new note
-					midiTime note_pos( pos_tact_64th );
+					midiTime note_pos( note::quantized(
+								midiTime( pos_tact_64th ),
+								quantization(), 0.9f ) );
 					midiTime note_len( newNoteLen() );
 		
 					note new_note( note_len, note_pos,
@@ -1371,7 +1379,7 @@ void pianoRoll::mousePressEvent( QMouseEvent * _me )
 							NOTES_PER_OCTAVE) );
 
 					note * created_new_note =
-						m_pattern->addNote( new_note );
+						m_pattern->addNote( new_note, FALSE );
 
 					// reset it so that it can be used for
 					// ops (move, resize) after this
@@ -1608,7 +1616,7 @@ void pianoRoll::mouseMoveEvent( QMouseEvent * _me )
 				m_currentNote->setVolume( vol );
 				m_pattern->update();
 				m_pattern->getInstrumentTrack()->processInEvent(
-					midiEvent( KEY_PRESSURE, 0, key_num,
+					midiEvent( KEY_PRESSURE, 0, m_lastKey,
 							vol * 127 / 100 ),
 								midiTime() );
 			}
