@@ -3,7 +3,7 @@
 /*
  * clipboard.cpp - the clipboard for patterns, notes etc.
  *
- * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -29,34 +29,34 @@
 #include "journalling_object.h"
 
 
-namespace clipboard
+
+
+clipboard::map clipboard::content;
+
+
+
+
+void clipboard::copy( journallingObject * _obj )
 {
-
-	map content;
+	QDomDocument doc;
+	QDomElement parent = doc.createElement( "clipboard" );
+	_obj->saveState( doc, parent );
+	content[_obj->nodeName()] = parent.firstChild().toElement();
+}
 
 
-	void copy( journallingObject * _obj )
+
+
+const QDomElement * clipboard::getContent( const QString & _node_name )
+{
+	if( content.find( _node_name ) != content.end() )
 	{
-		QDomDocument doc;
-		QDomElement parent = doc.createElement( "clipboard" );
-		_obj->saveState( doc, parent );
-		content[_obj->nodeName()] = parent.firstChild().toElement();
+		return( &content[_node_name] );
 	}
+	return( NULL );
+}
 
 
 
 
-	const QDomElement * getContent( const QString & _node_name )
-	{
-		if( content.find( _node_name ) != content.end() )
-		{
-			return( &content[_node_name] );
-		}
-		return( NULL );
-	}
-
-} ;
-
-
-
 #endif
