@@ -4,7 +4,7 @@
  * sample_track.cpp - implementation of class sampleTrack, a track which
  *                    provides arrangement of samples
  *
- * Copyright (c) 2005-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2005-2007 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -20,8 +20,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -44,23 +44,25 @@
 
 #endif
 
+#include "effect_label.h"
 
 #include "sample_track.h"
 #include "song_editor.h"
-#include "name_label.h"
 #include "embed.h"
+#include "engine.h"
 #include "templates.h"
-#include "buffer_allocator.h"
 #include "tooltip.h"
 #include "audio_port.h"
+#include "automation_pattern.h"
+#include "sample_play_handle.h"
 #include "string_pair_drag.h"
-#include "knob.h"
 #include "volume.h"
+#include "volume_knob.h"
 
 
 sampleTCO::sampleTCO( track * _track ) :
 	trackContentObject( _track ),
-	m_sampleBuffer( eng() )
+	m_sampleBuffer( new sampleBuffer )
 {
 #ifndef QT4
 	setBackgroundMode( Qt::NoBackground );
@@ -72,7 +74,7 @@ sampleTCO::sampleTCO( track * _track ) :
 
 	// we need to receive bpm-change-events, because then we have to
 	// change length of this TCO
-	connect( eng()->getSongEditor(), SIGNAL( tempoChanged( bpm_t ) ), this,
+	connect( engine::getSongEditor(), SIGNAL( tempoChanged( bpm_t ) ), this,
 						SLOT( updateLength( bpm_t ) ) );
 }
 
@@ -81,6 +83,7 @@ sampleTCO::sampleTCO( track * _track ) :
 
 sampleTCO::~sampleTCO()
 {
+	sharedObject::unref( m_sampleBuffer );
 }
 
 
@@ -95,21 +98,9 @@ void sampleTCO::changeLength( const midiTime & _length )
 
 
 
-void FASTCALL sampleTCO::play( sampleFrame * _ab, f_cnt_t _start_frame,
-							const fpab_t _frames )
-{
-	_start_frame = static_cast<Uint32>( tMax( 0.0f, _start_frame -
-							startPosition() *
-			eng()->getSongEditor()->framesPerTact() / 64 ) );
-	m_sampleBuffer.play( _ab, _start_frame, _frames );
-}
-
-
-
-
 const QString & sampleTCO::sampleFile( void ) const
 {
-	return( m_sampleBuffer.audioFile() );
+	return( m_sampleBuffer->audioFile() );
 }
 
 
@@ -117,13 +108,13 @@ const QString & sampleTCO::sampleFile( void ) const
 
 void sampleTCO::setSampleFile( const QString & _sf )
 {
-	m_sampleBuffer.setAudioFile( _sf );
+	m_sampleBuffer->setAudioFile( _sf );
 	updateLength();
 	update();
 	// set tooltip to filename so that user can see what sample this
 	// sample-tco contains
-	toolTip::add( this, ( m_sampleBuffer.audioFile() != "" ) ?
-					m_sampleBuffer.audioFile() :
+	toolTip::add( this, ( m_sampleBuffer->audioFile() != "" ) ?
+					m_sampleBuffer->audioFile() :
 					tr( "double-click to select sample" ) );
 }
 
@@ -159,9 +150,9 @@ void sampleTCO::dropEvent( QDropEvent * _de )
 	}
 	else if( stringPairDrag::decodeKey( _de ) == "sampledata" )
 	{
-		m_sampleBuffer.loadFromBase64(
+		m_sampleBuffer->loadFromBase64(
 					stringPairDrag::decodeValue( _de ) );
-		eng()->getSongEditor()->setModified();
+		engine::getSongEditor()->setModified();
 		updateLength();
 		update();
 		_de->accept();
@@ -177,11 +168,11 @@ void sampleTCO::dropEvent( QDropEvent * _de )
 
 void sampleTCO::mouseDoubleClickEvent( QMouseEvent * )
 {
-	QString af = m_sampleBuffer.openAudioFile();
-	if( af != "" && af != m_sampleBuffer.audioFile() )
+	QString af = m_sampleBuffer->openAudioFile();
+	if( af != "" && af != m_sampleBuffer->audioFile() )
 	{
 		setSampleFile( af );
-		eng()->getSongEditor()->setModified();
+		engine::getSongEditor()->setModified();
 	}
 }
 
@@ -230,7 +221,7 @@ void sampleTCO::paintEvent( QPaintEvent * _pe )
 			tMax( static_cast<int>( getSampleLength() *
 				pixelsPerTact() / 64 ), 1 ), height() - 4 );
 	p.setClipRect( QRect( 1, 1, width() - 2, height() - 2 ) );
-	m_sampleBuffer.visualize( p, r, _pe->rect() );
+	m_sampleBuffer->visualize( p, r, _pe->rect() );
 	if( r.width() < width() - 1 )
 	{
 		p.drawLine( r.x() + r.width(), r.y() + r.height() / 2,
@@ -253,9 +244,8 @@ void sampleTCO::paintEvent( QPaintEvent * _pe )
 
 midiTime sampleTCO::getSampleLength( void ) const
 {
-	return( static_cast<Sint32>( m_sampleBuffer.frames() /
-					eng()->getSongEditor()->framesPerTact() *
-									64 ) );
+	return( static_cast<Sint32>( m_sampleBuffer->frames() /
+						engine::framesPerTact64th() ) );
 }
 
 
@@ -278,7 +268,7 @@ void FASTCALL sampleTCO::saveSettings( QDomDocument & _doc,
 	if( sampleFile() == "" )
 	{
 		QString s;
-		_this.setAttribute( "data", m_sampleBuffer.toBase64( s ) );
+		_this.setAttribute( "data", m_sampleBuffer->toBase64( s ) );
 	}
 	// TODO: start- and end-frame
 }
@@ -295,7 +285,7 @@ void FASTCALL sampleTCO::loadSettings( const QDomElement & _this )
 	setSampleFile( _this.attribute( "src" ) );
 	if( sampleFile() == "" )
 	{
-		m_sampleBuffer.loadFromBase64( _this.attribute( "data" ) );
+		m_sampleBuffer->loadFromBase64( _this.attribute( "data" ) );
 	}
 	changeLength( _this.attribute( "len" ).toInt() );
 	if( _this.attribute( "muted" ).toInt() != muted() )
@@ -349,7 +339,7 @@ sampleTCOSettingsDialog::~sampleTCOSettingsDialog()
 
 void sampleTCOSettingsDialog::openSampleFile( void )
 {
-	QString af = m_sampleTCO->m_sampleBuffer.openAudioFile();
+	QString af = m_sampleTCO->m_sampleBuffer->openAudioFile();
 	if( af != "" )
 	{
 		setSampleFile( af );
@@ -363,7 +353,7 @@ void sampleTCOSettingsDialog::setSampleFile( const QString & _f )
 {
 	m_fileLbl->setText( _f );
 	m_sampleTCO->setSampleFile( _f );
-	eng()->getSongEditor()->setModified();
+	engine::getSongEditor()->setModified();
 }
 */
 
@@ -373,27 +363,28 @@ void sampleTCOSettingsDialog::setSampleFile( const QString & _f )
 
 sampleTrack::sampleTrack( trackContainer * _tc ) :
 	track( _tc ),
-	m_audioPort( new audioPort( tr( "Sample track" ), eng() ) ),
-	m_volume( 1.0f )
+	m_audioPort( new audioPort( tr( "Sample track" ) ) )
 {
 	getTrackWidget()->setFixedHeight( 32 );
 
+	m_trackLabel = new effectLabel( tr( "Sample track" ),
+					      getTrackSettingsWidget(), this );
+#if 0
 	m_trackLabel = new nameLabel( tr( "Sample track" ),
-					getTrackSettingsWidget(), eng() );
+						getTrackSettingsWidget() );
 	m_trackLabel->setPixmap( embed::getIconPixmap( "sample_track" ) );
+#endif
 	m_trackLabel->setGeometry( 26, 1, DEFAULT_SETTINGS_WIDGET_WIDTH-2, 29 );
 	m_trackLabel->show();
 
 	m_volumeKnob = new volumeKnob( knobSmall_17, getTrackSettingsWidget(),
-				    tr( "Channel volume" ), eng(), this );
+					    tr( "Channel volume" ), this );
 	m_volumeKnob->setRange( MIN_VOLUME, MAX_VOLUME, 1.0f );
 	m_volumeKnob->setInitValue( DEFAULT_VOLUME );
 	m_volumeKnob->setHintText( tr( "Channel volume:" ) + " ", "%" );
 	m_volumeKnob->move( 4, 4 );
 	m_volumeKnob->setLabel( tr( "VOL" ) );
 	m_volumeKnob->show();
-	connect( m_volumeKnob, SIGNAL( valueChanged( float ) ), 
-		 this, SLOT( setVolume( float ) ) );
 #ifdef QT4
 	m_volumeKnob->setWhatsThis(
 #else
@@ -411,21 +402,12 @@ sampleTrack::sampleTrack( trackContainer * _tc ) :
 
 sampleTrack::~sampleTrack()
 {
+	engine::getMixer()->removePlayHandles( this );
 	delete m_audioPort;
 }
 
 
 
-void sampleTrack::setVolume( float _new_volume )
-{
-	if( _new_volume <= MAX_VOLUME )
-	{
-		m_volume = _new_volume / 100.0f;
-	}
-}
-
-
-
 
 track::trackTypes sampleTrack::type( void ) const
 {
@@ -436,53 +418,39 @@ track::trackTypes sampleTrack::type( void ) const
 
 
 bool FASTCALL sampleTrack::play( const midiTime & _start,
-						const f_cnt_t _start_frame,
-						const fpab_t _frames,
-						const f_cnt_t _frame_base,
+						const fpp_t _frames,
+						const f_cnt_t _offset,
 							Sint16 /*_tco_num*/ )
 {
 	sendMidiTime( _start );
 
-	vlist<trackContentObject *> tcos;
-	getTCOsInRange( tcos, _start, _start+static_cast<Sint32>( _frames * 64 /
-				eng()->getSongEditor()->framesPerTact() ) );
+	m_audioPort->getEffects()->startRunning();
+	bool played_a_note = FALSE;	// will be return variable
 
-	if ( tcos.size() == 0 )
+	for( csize i = 0; i < numOfTCOs(); ++i )
 	{
-		return( FALSE );
-	}
-
-	sampleFrame * buf = bufferAllocator::alloc<sampleFrame>( _frames );
-
-	volumeVector v = { m_volume, m_volume
-#ifndef DISABLE_SURROUND
-					, m_volume, m_volume
-#endif
-			} ;
-	float fpt = eng()->getSongEditor()->framesPerTact();
-
-	for( vlist<trackContentObject *>::iterator it = tcos.begin();
-							it != tcos.end(); ++it )
-	{
-		sampleTCO * st = dynamic_cast<sampleTCO *>( *it );
-		if( st != NULL && !st->muted() )
+		trackContentObject * tco = getTCO( i );
+		if( tco->startPosition() != _start )
 		{
-			st->play( buf, _start_frame +
-					static_cast<Uint32>( _start.getTact() *
-									fpt ),
-					_frames );
-			eng()->getMixer()->bufferToPort( buf, _frames,
-							_frame_base +
-							static_cast<Uint32>(
-					st->startPosition().getTact64th() *
-							fpt / 64.0f ), v,
-							m_audioPort );
+			continue;
+		}
+		sampleTCO * st = dynamic_cast<sampleTCO *>( tco );
+		if( !st->muted() )
+		{
+			samplePlayHandle * handle = new samplePlayHandle( st );
+			connect( m_volumeKnob, SIGNAL( valueChanged( float ) ),
+					handle, SLOT( setVolume( float ) ) );
+			handle->setVolume( m_volumeKnob->value() );
+//TODO: do we need sample tracks in BB editor?
+//			handle->setBBTrack( bb_track );
+			handle->setOffset( _offset );
+			// send it to the mixer
+			engine::getMixer()->addPlayHandle( handle );
+			played_a_note = TRUE;
 		}
 	}
 
-	bufferAllocator::free( buf );
-
-	return( TRUE );
+	return( played_a_note );
 }
 
 
@@ -501,7 +469,10 @@ void sampleTrack::saveTrackSpecificSettings( QDomDocument & _doc,
 							QDomElement & _this )
 {
 	_this.setAttribute( "name", m_trackLabel->text() );
+	m_trackLabel->saveState( _doc, _this );
+#if 0
 	_this.setAttribute( "icon", m_trackLabel->pixmapFile() );
+#endif
 	m_volumeKnob->saveSettings( _doc, _this, "vol" );
 }
 
@@ -511,30 +482,25 @@ void sampleTrack::saveTrackSpecificSettings( QDomDocument & _doc,
 void sampleTrack::loadTrackSpecificSettings( const QDomElement & _this )
 {
 	m_trackLabel->setText( _this.attribute( "name" ) );
+	QDomNode node = _this.firstChild();
+	while( !node.isNull() )
+	{
+		if( node.isElement() )
+		{
+			if( m_trackLabel->nodeName() == node.nodeName() )
+			{
+				m_trackLabel->restoreState( node.toElement() );
+			}
+		}
+		node = node.nextSibling();
+	}
+#if 0
 	if( _this.attribute( "icon" ) != "" )
 	{
 		m_trackLabel->setPixmapFile( _this.attribute( "icon" ) );
 	}
-	if( _this.attribute( "vol" ) != "" )
-	{
-		m_volume = _this.attribute( "vol" ).toFloat();
-		m_volumeKnob->setInitValue( m_volume * 100.0f );
-	}
-	else
-	{
-		QDomNode node = _this.namedItem(
-					automationPattern::classNodeName() );
-		if( node.isElement() && node.namedItem( "vol" ).isElement() )
-		{
-			m_volumeKnob->loadSettings( _this, "vol" );
-			m_volume = m_volumeKnob->value() / 100.0f;
-		}
-		else
-		{
-			m_volume = 1.0;
-			m_volumeKnob->setInitValue( 100.0f );
-		}
-	}
+#endif
+	m_volumeKnob->loadSettings( _this, "vol" );
 }
 
 
