@@ -1,7 +1,9 @@
+#ifndef SINGLE_SOURCE_COMPILE
+
 /*
  * rename_dialog.cpp - implementation of dialog for renaming something
  *
- * Copyright (c) 2004-2005 Tobias Doerffel <tobydox/at/users.sourceforge.net>
+ * Copyright (c) 2004-2006 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  * 
  * This file is part of Linux MultiMedia Studio - http://lmms.sourceforge.net
  *
@@ -17,8 +19,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program (see COPYING); if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  *
  */
 
@@ -27,8 +29,8 @@
 
 #ifdef QT4
 
-#include <QLineEdit>
-#include <QKeyEvent>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QLineEdit>
 
 #else
 
@@ -88,3 +90,5 @@ void renameDialog::textChanged( const QString & _new_string )
 
 #include "rename_dialog.moc"
 
+
+#endif
